@@ -7,7 +7,7 @@
 enum bindtype {
 	NULL_BIND,
 	STRING_BIND,
-	LONG_BIND,
+	INTEGER_BIND,
 	DOUBLE_BIND,
 	BLOB_BIND,
 	CLOB_BIND,
@@ -20,19 +20,18 @@ class bindvar {
 		char	*variable;
 		union {
 			char	*stringval;
-			long	longval;
+			int64_t	integerval;
 			struct {
-				double	value;
-				unsigned short	precision;
-				unsigned short	scale;
+				double		value;
+				uint32_t	precision;
+				uint32_t	scale;
 			} doubleval;
-			char	*lobval;
-			unsigned short	cursorid;
+			char		*lobval;
+			uint16_t	cursorid;
 		} value;
-		unsigned long	valuesize;
+		uint32_t	valuesize;
 		bindtype	type;
-		unsigned short	send;
-		
+		bool		send;
 };
 
 #endif
