@@ -24,7 +24,7 @@ public class SQLRConnection {
 	 *  connect to "server" on "port".  If it is 
 	 *  NULL or "" then no attempt will be made to 
 	 *  connect through the socket.  */
-	public SQLRConnection(String server, int port, String socket,
+	public SQLRConnection(String server, short port, String socket,
 						String user, String password,
 						int retrytime, int tries) {
 		connection=alloc(server,port,socket,
@@ -47,19 +47,23 @@ public class SQLRConnection {
 	/** Returns the inet port that the connection is 
 	 *  communicating over. This parameter may be 
 	 *  passed to another connection for use in
-	 *  the resumeSession() method. */
-	public native int	getConnectionPort();
+	 *  the resumeSession() method.
+	 *  Note: the value returned by this method is only
+	 *  valid after a call to suspendSession().*/
+	public native short	getConnectionPort();
 
 	/** Returns the unix socket that the connection 
 	 *  is communicating over. This parameter may be 
 	 *  passed to another connection for use in
-	 *  the resumeSession() method. */
+	 *  the resumeSession() method.
+	 *  Note: the value returned by this method is only
+	 *  valid after a call to suspendSession().*/
 	public native String	getConnectionSocket();
 
 	/** Resumes a session previously left open 
 	 *  using suspendSession().
 	 *  Returns 1 on success and 0 on failure. */
-	public native boolean	resumeSession(int port, String socket);
+	public native boolean	resumeSession(short port, String socket);
 
 
 	/** Returns 1 if the database is up and 0
@@ -99,8 +103,8 @@ public class SQLRConnection {
 
 	/** connection is used internally, it's just
 	 *  public to make the JNI wrapper work faster.  */
-	public int	connection;
-	private native int	alloc(String server, int port, 
+	public long	connection;
+	private native long	alloc(String server, short port, 
 						String socket, String user, 
 						String password, 
 						int retrytime, int tries);
