@@ -16,7 +16,7 @@
 // | Author: David Muse <ssb@php.net>                                    |
 // +----------------------------------------------------------------------+
 //
-// $Id: sqlrelay.php,v 1.3.2.4 2005/06/30 02:54:47 mused Exp $
+// $Id: sqlrelay.php,v 1.15.2.2 2006/08/05 03:08:23 mused Exp $
 //
 // Database independent query interface definition for PHP's SQLRelay
 // extension.
@@ -27,11 +27,8 @@ require_once "DB/common.php";
 class DB_sqlrelay_cursor
 {
     var $cursor;
-    var $identity = "";
     var $connection;
     var $rownum = 0;
-    var $prepare_tokens = array();
-    var $prepare_types = array();
 
     function DB_sqlrelay_cursor($cur,$connection)
     {
@@ -46,10 +43,14 @@ class DB_sqlrelay extends DB_common
     // {{{ properties
 
     var $connection;
+    var $identity = "";
     var $phptype, $dbsyntax;
     var $autocommit = false;
     var $fetchmode = DB_FETCHMODE_ORDERED; /* Default fetch mode */
     var $affectedrows = 0;
+    var $prepare_types = array();
+    var $is_select = array();
+
 
     // }}}
     // {{{ constructor
@@ -89,16 +90,8 @@ class DB_sqlrelay extends DB_common
     function connect($dsninfo, $persistent = false)
     {
 
-        $hasloadextension = false;
-        foreach (get_class_methods(get_class($this)) as $method) {
-printf("$method\n");
-            if ($method == "loadextension" || $method == "loadExtension") {
-                $hasloadextension = true;
-                break;
-            }
-        }
-
-        if ($hasloadextension == true) {
+        if (method_exists($this,'loadExtension') || 
+                            method_exists($this,'loadextension')) {
             if (!PEAR::loadExtension('sql_relay')) {
                 return $this->raiseError(DB_ERROR_EXTENSION_NOT_FOUND);
             }
@@ -110,17 +103,13 @@ printf("$method\n");
 
         $this->dsn = $dsninfo;
 
-        $host = $dsninfo['hostspec'];
-        $port = $dsninfo['port'];
-        $socket = $dsninfo['socket'];
-        $user = $dsninfo['username'];
-        $pw = $dsninfo['password'];
-        $retrytime = 1;
-        $tries = 0;
-
-        $this->connection = sqlrcon_alloc($host, $port, $socket,
-                                            $user, $pw, $retrytime, $tries);
-sqlrcon_debugOn($this->connection);
+        $this->connection = sqlrcon_alloc($dsninfo['hostspec'],
+                                            $dsninfo['port'],
+                                            $dsninfo['socket'],
+                                            $dsninfo['username'],
+                                            $dsninfo['password'],
+                                            0,1);
+#sqlrcon_debugOn($this->connection);
         return DB_OK;
     }
 
@@ -141,6 +130,16 @@ sqlrcon_debugOn($this->connection);
         return true;
     }
 
+    // }}}
+    // {{{ isSelect()
+
+    function isSelect($query)
+    {
+        return ((preg_match('/^\s*SHOW TABLES\s*/si', $query) ||
+                    preg_match('/^\s*\(?\s*SELECT\s+/si', $query)) &&
+                    !preg_match('/^\s*\(?\s*SELECT\s+INTO\s+/si', $query));
+    }
+
     // }}}
     // {{{ simpleQuery()
 
@@ -159,6 +158,16 @@ sqlrcon_debugOn($this->connection);
     {
 
         $cursor = sqlrcur_alloc($this->connection);
+
+        if ($this->options['portability'] & DB_PORTABILITY_LOWERCASE) {
+            sqlrcur_lowerCaseColumnNames ($cursor);
+        }
+        if ($this->options['portability'] & DB_PORTABILITY_NULL_TO_EMPTY) {
+            sqlrcur_getNullsAsEmptyStrings ($cursor);
+        } else {
+            sqlrcur_getNullsAsNulls ($cursor);
+        }
+
         sqlrcur_setResultSetBufferSize($cursor,100);
         if (!sqlrcur_sendQuery($cursor, $query)) {
             $this->affectedrows = 0;
@@ -173,10 +182,8 @@ sqlrcon_debugOn($this->connection);
         If there are any affected rows, then the query was definitely not a
         select, otherwise there's no good way to know what kind of query it was
         except by parsing it. */
-        if ($this->affectedrows <= 0 &&
-                preg_match('/^\s*\(?\s*SELECT\s+/si', $query) &&
-                    !preg_match('/^\s*\(?\s*SELECT\s+INTO\s/si', $query)) {
-            return new DB_sqlrelay_cursor($cursor);
+        if ($this->isSelect($query)) {
+            return new DB_sqlrelay_cursor($cursor,$this->connection);
         }
 
         sqlrcur_free($cursor);
@@ -199,10 +206,63 @@ sqlrcon_debugOn($this->connection);
 
     function prepare($query)
     {
+        if ($this->identity == "") {
+            $this->identity = sqlrcon_identify($this->connection);
+        }
+
         $cursor = sqlrcur_alloc($this->connection);
+
+        if ($this->options['portability'] & DB_PORTABILITY_LOWERCASE) {
+            sqlrcur_lowerCaseColumnNames ($cursor);
+        }
+        if ($this->options['portability'] & DB_PORTABILITY_NULL_TO_EMPTY) {
+            sqlrcur_getNullsAsEmptyStrings ($cursor);
+        } else {
+            sqlrcur_getNullsAsNulls ($cursor);
+        }
+
         sqlrcur_setResultSetBufferSize($cursor,100);
-        sqlrcur_prepareQuery($cursor, $query);
-        return new DB_sqlrelay_cursor($cursor,$connection);
+
+        # handle ?-delimited bind variables by rewriting the query and creating
+        # : or @ delimited variables
+        # for db2 which already uses ?-delimited variables, we don't need
+        # to do this...
+        # FIXME: handle postgresql 8 and mysql 4.1
+        if ($this->identity == "db2" || $this->identity == "interbase") {
+            $newquery = $query;
+        } else {
+            $paramindex = 0;
+            $newquery = '';
+            $types = array();
+            $inquotes = false;
+            for ($i = 0; $i < strlen($query); $i++) {
+                if ($query[$i] == '\'') {
+                    $inquotes = !$inquotes;
+                } else if (($query[$i] == '?' || $query[$i] == '&') &&
+                                                            !$inquotes) {
+                    if ($query[$i] == '?') {
+                        $types[$paramindex] = DB_PARAM_SCALAR;
+                    } else {
+                        $types[$paramindex] = DB_PARAM_OPAQUE;
+                    }
+                    if ($this->identity == "sybase" ||
+                            $this->identity == "freetds") {
+                        $newquery .= $query[$i] . "@bind" . $paramindex;
+                    } else {
+                        $newquery .= $query[$i] . ":bind" . $paramindex;
+                    }
+                    $paramindex++;
+                    continue;
+                }
+                $newquery .= $query[$i]
+            }        
+            $this->prepare_types[(int)$cursor] = $types;
+        }
+
+        $this->is_select[(int)$cursor] = $this->isSelect($newquery);
+
+        sqlrcur_prepareQuery($cursor, $newquery);
+        return new DB_sqlrelay_cursor($cursor,$this->connection);
     }
 
     // }}}
@@ -276,8 +336,8 @@ sqlrcon_debugOn($this->connection);
      */
     function buildManipSQL($table, $table_fields, $mode, $where = false)
     {
-        if ($identity == "") {
-            $idenity = sqlrcon_identify($this->connection);
+        if ($this->identity == "") {
+            $this->identity = sqlrcon_identify($this->connection);
         }
         if (count($table_fields) == 0) {
             return $this->raiseError(DB_ERROR_NEED_MORE_DATA);
@@ -295,10 +355,12 @@ sqlrcon_debugOn($this->connection);
                         $values .= ',';
                     }
                     $names .= $value;
-                    if ($identity != "sybase" && $identity != "freetds") {
-                        $values .= ":$value";
-                    } else {
+                    # FIXME: handle other db formats too
+                    if ($this->identity == "sybase" ||
+                                $this->identity == "freetds") {
                         $values .= "@$value";
+                    } else {
+                        $values .= ":$value";
                     }
                 }
                 return "INSERT INTO $table ($names) VALUES ($values)";
@@ -310,10 +372,12 @@ sqlrcon_debugOn($this->connection);
                     } else {
                         $set .= ',';
                     }
-                    if ($identity != "sybase" && $identity != "freetds") {
-                        $set .= "$value = :$value";
-                    } else {
+                    # FIXME: handle other db formats too
+                    if ($this->identity == "sybase" ||
+                                $this->identity == "freetds") {
                         $set .= "$value = @$value";
+                    } else {
+                        $set .= "$value = :$value";
                     }
                 }
                 $sql = "UPDATE $table SET $set";
@@ -347,18 +411,57 @@ sqlrcon_debugOn($this->connection);
 
     function &execute(&$sqlrcursor, $data = false)
     {
+
         sqlrcur_clearBinds($sqlrcursor->cursor);
-        if ($data) {
+
+        # handle ?/& binds...
+        $types=&$this->prepare_types[(int)$sqlrcursor->cursor];
+        $typessize = sizeof($types);
+        if ($typessize > 0 && $typessize != sizeof($data)) {
+            return $this->raiseError(DB_ERROR_MISMATCH);
+        }
+
+        for ($i = 0; $i < $typessize; $i++) {
+            if (is_array($data)) {
+                $pdata[$i] = &$data[$i];
+            } else {
+                $pdata[$i] = &$data;
+            }
+            if ($types[$i] == DB_PARAM_OPAQUE) {
+                $fp = fopen($pdata[$i], "r");
+                $pdata[$i] = '';
+                if ($fp) {
+                    while (($buf = fread($fp, 4096)) != false) {
+                        $pdata[$i] .= $buf;
+                    }
+                }
+            }
+
+            sqlrcur_inputBind($sqlrcursor->cursor,"bind" . $i, $pdata[$i]);
+        }
+
+        # handle native SQL Relay binds...
+        if (!$typessize && $data) {
             foreach ($data as $index=>$value) {
                 sqlrcur_inputBind($sqlrcursor->cursor, $index, $value);
             }
         }
+
         if (!sqlrcur_executeQuery($sqlrcursor->cursor)) {
             $error = sqlrcur_errorMessage($sqlrcursor->cursor);
             $this->freeResult($sqlrcursor);
             return $this->raiseError(DB_ERROR, null, null, null, $error);
         }
-        return $sqlrcursor;
+
+        /* If the query was a select, return a cursor, otherwise return DB_OK.
+        If there are any affected rows, then the query was definitely not a
+        select, otherwise there's no good way to know what kind of query it was
+        except by parsing it. */
+        if ($this->is_select[(int)$sqlrcursor->cursor]) {
+            return new DB_result($this,$sqlrcursor);
+        }
+
+        return DB_OK;
     }
 
     // }}}
@@ -411,23 +514,32 @@ sqlrcon_debugOn($this->connection);
     function freeResult(&$sqlrcursor)
     {
         if (is_resource($sqlrcursor)) {
+            unset($this->prepare_types[(int)$sqlrcursor->cursor]);
+            unset($this->is_select[(int)$sqlrcursor->cursor]);
             sqlrcur_free($sqlrcursor->cursor);
-            return true;
         }
-
-        // $sqlrcursor is a prepared query handle
-        $sqlrcursor = (int)$sqlrcursor;
-        if (!isset($this->prepare_tokens[$sqlrcursor])) {
-            return false;
-        }
-
-        $this->prepare_types = array();
-        $this->prepare_tokens = array();
-
         return true;
     }
 
     // }}}
+    // {{{ freePrepared()
+
+    /**
+     * Frees the internal resources associated with a prepared query
+     *
+     * @param resource $stmt           the prepared statement's PHP resource
+     * @param bool     $free_resource  should the PHP resource be freed too?
+     *                                  Use false if you need to get data
+     *                                  from the result set later.
+     *
+     * @return bool  TRUE on success, FALSE if $result is invalid
+     *
+     * @see DB_common::prepare()
+     */
+    function freePrepared($stmt, $free_resource = true)
+    {
+        return true;
+    }
     // {{{ numCols()
 
     /**
@@ -488,8 +600,9 @@ sqlrcon_debugOn($this->connection);
         if (sqlrcon_commit($this->connection) == 1) {
             return DB_OK;
         } else {
+            # FIXME: need some way to get a rollback error
             return $this->raiseError(DB_ERROR, null, null, null,
-                                    sqlrcon_errorMessage($this->connection));
+                                                "commit failed");
         }
     }
 
@@ -504,8 +617,9 @@ sqlrcon_debugOn($this->connection);
         if (sqlrcon_rollback($this->connection) == 1) {
             return DB_OK;
         } else {
+            # FIXME: need some way to get a rollback error
             return $this->raiseError(DB_ERROR, null, null, null,
-                                    sqlrcon_errorMessage($this->connection));
+                                                "rollback failed");
         }
     }
 
@@ -524,10 +638,131 @@ sqlrcon_debugOn($this->connection);
         return $this->affectedrows;
     }
 
+    // }}}
+    // {{{ nextId()
+
+    /**
+     * Returns the next free id in a sequence
+     *
+     * @param string  $seq_name  name of the sequence
+     * @param boolean $ondemand  when true, the seqence is automatically
+     *                            created if it does not exist
+     *
+     * @return int  the next id number in the sequence.
+     *               A DB_Error object on failure.
+     *
+     */
+
+    function nextId($seq_name, $ondemand = true)
+    {
+
+        # get the sequence name
+        $seqname = $this->getSequenceName($seq_name);
+
+        # initialize the sequence query
+        $seqquery = "";
+
+        # figure out what kind of db we're using and build the appropriate query
+        if ($this->identity == "") {
+            $this->identity = sqlrcon_identify($this->connection);
+        }
+        if ($this->identity == "oracle8" || $this->identity == "oracle7") {
+            $seqquery = "SELECT ${seqname}.nextval FROM dual";
+        } else {
+            # FIXME: implement for other DB's
+            return $this->raiseError(DB_ERROR_NOT_CAPABLE);
+        }
+
+        # try to get the value from the sequence
+        $result =& $this->query($seqquery);
+
+        # if it failed and we're creating sequences on-demand, try to create
+        # the sequence and then re-run the query
+        if (DB::isError($result) && $ondemand) {
+
+            # FIXME: if we got an error, we assume that the sequence
+            # didn't exist and we try to create it that may not actually be the
+            # case, we need to check the error code
+            $result = $this->createSequence($seq_name);
+            if (!DB::isError($result)) {
+                $result =& $this->query($seqquery);
+            }
+        }
+
+        # if any of the previous stuff generated an error, return it
+        if (DB::isError($result)) {
+            return $this->raiseError($result);
+        }
+
+        # otherwise, return the first field
+        $arr = $result->fetchRow(DB_FETCHMODE_ORDERED);
+        return $arr[0];
+    }
+
+    // }}}
+    // {{{ createSequence()
+
+    /**
+     * Creates a new sequence
+     *
+     * @param string $seq_name  name of the new sequence
+     *
+     * @return int  DB_OK on success.  A DB_Error object on failure.
+     *
+     */
+
+    function createSequence($seq_name)
+    {
+        $seqquery="";
+
+        if ($this->identity == "") {
+            $this->identity = sqlrcon_identify($this->connection);
+        }
+
+        if ($this->identity == "oracle8" || $this->identity == "oracle7") {
+            $seqquery = "CREATE SEQUENCE " . $this->getSequenceName($seq_name);
+        } else {
+            # FIXME: implement for other DB's
+            return $this->raiseError(DB_ERROR_NOT_CAPABLE);
+        }
+
+        return $this->query($seqquery);
+    }
+
+    // }}}
+    // {{{ dropSequence()
+
+    /**
+     * Deletes a sequence
+     *
+     * @param string $seq_name  name of the sequence to be deleted
+     *
+     * @return int  DB_OK on success.  A DB_Error object on failure.
+     *
+     */
+
+    function dropSequence($seq_name)
+    {
+        $seqquery = "";
+
+        if ($this->identity == "") {
+            $this->identity = sqlrcon_identify($this->connection);
+        }
+
+        if ($this->identity == "oracle8" || $this->identity == "oracle7") {
+            $seqquery = "DROP SEQUENCE " . $this->getSequenceName($seq_name);
+        } else {
+            # FIXME: implement for other DB's
+            return $this->raiseError(DB_ERROR_NOT_CAPABLE);
+        }
+
+        return $this->query($seqquery);
+    }
+
     // }}}
     // {{{ tableInfo()
 
-    function tableInfo($sqlrcursor, $mode = null)
+    function tableInfo($result, $mode = null)
     {
 
         /*
@@ -567,15 +802,20 @@ sqlrcon_debugOn($this->connection);
          *      DB_TABLEINFO_ORDERTABLE * or with DB_TABLEINFO_FULL
          */
 
-        if (is_string($sqlrcursor)) {
+        if (is_string($result)) {
             // if $result is a string, then we want information about a
             // table without a resultset else we want information about a
             // resultset, this is not yet supported
             return null;
-        } else if (empty($sqlrcursor) || empty($sqlrcursor)) {
+        } else if (empty($result)) {
+            return null;
+        } else if ($result==DB_OK) {
             return null;
         }
 
+        # extract the sqlrcursor
+        $sqlrcursor = $result->result;
+
         $count = sqlrcur_colCount($sqlrcursor->cursor);
 
         if (empty($mode)) {
