@@ -44,6 +44,8 @@ class sqlrconnection:
         communicating over. This parameter may be 
         passed to another connection for use in
         the resumeSession() method.
+        Note: the value returned by this method is
+        only valid after a call to suspendSession().
         """
         return CSQLRelay.getConnectionPort(self.connection)
 
@@ -53,6 +55,8 @@ class sqlrconnection:
         communicating over. This parameter may be 
         passed to another connection for use in
         the resumeSession() method.
+        Note: the value returned by this method is
+        only valid after a call to suspendSession().
         """
         return CSQLRelay.getConnectionSocket(self.connection)
 
@@ -290,6 +294,9 @@ class sqlrcursor:
     def substitution(self, variable, value, precision=0, scale=0):
         """
         Define a substitution variable.
+	Returns true if the variable was successfully substituted or false if
+	the variable isn't a string, integer or floating point number, or if
+	precision and scale aren't provided for a floating point number.
         """
         return CSQLRelay.substitution(self.cursor,variable,value,precision,scale)
 
@@ -310,6 +317,9 @@ class sqlrcursor:
     def inputBind(self, variable, value, precision=0, scale=0):
         """
         Define an input bind varaible.
+	Returns true if the variable was successfully bound or false if the
+	variable isn't a string, integer or floating point number, or if
+	precision and scale aren't provided for a floating point number.
         """
         return CSQLRelay.inputBind(self.cursor, variable, value, precision, scale)
 
@@ -325,11 +335,23 @@ class sqlrcursor:
         """
         return CSQLRelay.inputBindClob(self.cursor, variable, value, length)
 
-    def defineOutputBind(self, variable, length):
+    def defineOutputBindString(self, variable, length):
         """
         Define an output bind varaible.
         """
-        return CSQLRelay.defineOutputBind(self.cursor, variable, length)
+        return CSQLRelay.defineOutputBindString(self.cursor, variable, length)
+
+    def defineOutputBindInteger(self, variable):
+        """
+        Define an output bind varaible.
+        """
+        return CSQLRelay.defineOutputBindInteger(self.cursor, variable)
+
+    def defineOutputBindDouble(self, variable):
+        """
+        Define an output bind varaible.
+        """
+        return CSQLRelay.defineOutputBindDouble(self.cursor, variable)
 
     def defineOutputBindBlob(self, variable):
         """
@@ -352,12 +374,18 @@ class sqlrcursor:
     def substitutions(self, variables, values, precisions=None, scales=None):
         """
         Define substitution variables.
+	Returns true if the variables were successfully substituted or false if
+	one of the variables wasn't a string, integer or floating point number,
+	or if precision and scale weren't provided for a floating point number.
         """
         return CSQLRelay.substitutions(self.cursor,variables,values,precisions,scales)
 
     def inputBinds(self, variables, values, precisions=None, scales=None):
         """
         Define input bind variables.
+	Returns true if the variables were successfully bound or false if one
+	of the variables wasn't a string, integer or floating point number,
+	or if precision and scale weren't provided for a floating point number.
         """
         return CSQLRelay.inputBinds(self.cursor,variables,values,precisions,scales)
         
@@ -386,28 +414,42 @@ class sqlrcursor:
         """
         return CSQLRelay.fetchFromBindCursor(self.cursor)
 
-    def getOutputBind(self, variable):
+    def getOutputBindString(self, variable):
         """
         Get the value stored in a previously
         defined output bind variable.
         """
-        return CSQLRelay.getOutputBind(self.cursor, variable)
+        return CSQLRelay.getOutputBindString(self.cursor, variable)
 
-    def getOutputBindAsLong(self, variable):
+    def getOutputBindBlob(self, variable):
+        """
+        Get the value stored in a previously
+        defined output bind variable.
+        """
+        return CSQLRelay.getOutputBindBlob(self.cursor, variable)
+
+    def getOutputBindClob(self, variable):
+        """
+        Get the value stored in a previously
+        defined output bind variable.
+        """
+        return CSQLRelay.getOutputBindClob(self.cursor, variable)
+
+    def getOutputBindInteger(self, variable):
         """
         Get the value stored in a previously
         defined output bind variable as a long
         integer.
         """
-        return CSQLRelay.getOutputBindAsLong(self.cursor, variable)
+        return CSQLRelay.getOutputBindInteger(self.cursor, variable)
 
-    def getOutputBindAsDouble(self, variable):
+    def getOutputBindDouble(self, variable):
         """
         Get the value stored in a previously
         defined output bind variable as a double
         precision floating point number.
         """
-        return CSQLRelay.getOutputBindAsDouble(self.cursor, variable)
+        return CSQLRelay.getOutputBindDouble(self.cursor, variable)
 
     def getOutputBindLength(self, variable):
         """
@@ -515,11 +557,11 @@ class sqlrcursor:
         """
         return CSQLRelay.getField(self.cursor, row, col)
 
-    def getFieldAsLong(self, row, col):
+    def getFieldAsInteger(self, row, col):
         """
         Returns the specified field as a long integer.
         """
-        return CSQLRelay.getFieldAsLong(self.cursor, row, col)
+        return CSQLRelay.getFieldAsInteger(self.cursor, row, col)
 
     def getFieldAsDouble(self, row, col):
         """
@@ -681,15 +723,6 @@ class sqlrcursor:
         """
         return CSQLRelay.getLongest(self.cursor, col)
 
-    def getResultSetId(self):
-        """
-        Returns the internal ID of this result set.
-        This parameter may be passed to another 
-        cursor for use in the resumeResultSet() 
-        method.
-        """
-        return CSQLRelay.getResultSetId(self.cursor)
-
     def suspendResultSet(self):
         """
         Tells the server to leave this result
@@ -700,6 +733,17 @@ class sqlrcursor:
         """
         return CSQLRelay.suspendResultSet(self.cursor)
 
+    def getResultSetId(self):
+        """
+        Returns the internal ID of this result set.
+        This parameter may be passed to another 
+        cursor for use in the resumeResultSet() 
+        method.
+        Note: the value returned by this method is
+        only valid after a call to suspendResultSet().
+        """
+        return CSQLRelay.getResultSetId(self.cursor)
+
     def resumeResultSet(self, id):
         """
         Resumes a result set previously left open 
