@@ -3,6 +3,9 @@
 #define DEFAULT_ID "defaultid"
 	// default id for listeners/connections
 
+#define DEFAULT_ADDRESSES "0.0.0.0"
+	// default addresses for listeners/connections
+
 #define DEFAULT_PORT "9000"
 	// default port to listen on
 
@@ -60,6 +63,18 @@
 #define DEFAULT_DEBUG "none"
 	// default tiers to debug on
 
+#define DEFAULT_MAXQUERYSIZE "65536"
+	// default max query size
+
+#define DEFAULT_MAXSTRINGBINDVALUELENGTH "32768"
+	// default max string bind value length
+
+#define DEFAULT_MAXLOBBINDVALUELENGTH "71680"
+	// default lob bind value length
+
+#define DEFAULT_IDLECLIENTTIMEOUT "-1"
+	// default idle client timeout
+
 #define DEFAULT_USER "user"
 	// default user name for authentication
 
@@ -75,7 +90,44 @@
 #define DEFAULT_METRIC "1"
 	// default metric
 
+#define DEFAULT_BEHINDLOADBALANCER "no"
+	// default behind-load-balancer flag
 
+#define DEFAULT_SID_ENABLED false
+	// default sid-enabled flag
+
+#define DEFAULT_SID_HOST ""
+	// default sid-host
+
+#define DEFAULT_SID_PORT 0
+	// default sid-port
+
+#define DEFAULT_SID_SOCKET ""
+	// default sid-socket
+
+#define DEFAULT_SID_USER "user"
+	// default sid-user
+
+#define DEFAULT_SID_PASSWORD "password"
+	// default sid-password
+
+#define DEFAULT_ROUTER_HOST "localhost"
+	// default router host
+
+#define DEFAULT_ROUTER_PORT "9000"
+	// default router port
+
+#define DEFAULT_ROUTER_SOCKET "/tmp/sqlrelay.socket"
+	// default router socket
+
+#define DEFAULT_ROUTER_USER "user"
+	// default router user
+
+#define DEFAULT_ROUTER_PASSWORD "password"
+	// default router password
+
+#define DEFAULT_ROUTER_PATTERN ".*"
+	// default router pattern
 
 // cachemanager/sqlrclient parameters
 #define DEFAULT_INTERVAL 30
