@@ -28,15 +28,18 @@
 
 #include <defines.h>
 
+#include <sqlrelay/sqlrclient.h>
+
 #ifdef RUDIMENTS_NAMESPACE
 using namespace rudiments;
 #endif
 
-class sqlrconnection : public daemonprocess, public listener, public debugfile {
-	friend class sqlrcursor;
+class sqlrconnection_svr :
+		public daemonprocess, public listener, public debugfile {
+	friend class sqlrcursor_svr;
 	public:
-			sqlrconnection();
-		virtual	~sqlrconnection();
+			sqlrconnection_svr();
+		virtual	~sqlrconnection_svr();
 
 		bool	initConnection(int argc, const char **argv,
 						bool detachbeforeloggingin);
@@ -46,7 +49,8 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 
 	protected:
 		// interface definition
-		virtual	int	getNumberOfConnectStringVars()=0;
+		virtual	uint16_t	getNumberOfConnectStringVars()=0;
+		virtual bool	supportsNativeBinds();
 		virtual	void	handleConnectString()=0;
 		virtual	bool	logIn()=0;
 		virtual	void	logOut()=0;
@@ -59,26 +63,25 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		virtual const char	*pingQuery();
 		virtual bool		ping();
 		virtual const char	*identify()=0;
-		virtual sqlrcursor	*initCursor()=0;
-		virtual void	deleteCursor(sqlrcursor *curs)=0;
-		virtual	short	nonNullBindValue();
-		virtual	short	nullBindValue();
+		virtual sqlrcursor_svr	*initCursor()=0;
+		virtual void	deleteCursor(sqlrcursor_svr *curs)=0;
+		virtual	int16_t	nonNullBindValue();
+		virtual	int16_t	nullBindValue();
 		virtual char	bindVariablePrefix();
-		virtual bool	bindValueIsNull(short isnull);
-		virtual	bool	skipRows(sqlrcursor *cursor,
-						unsigned long rows);
+		virtual bool	bindValueIsNull(int16_t isnull);
+		virtual	bool	skipRows(sqlrcursor_svr *cursor, uint64_t rows);
 		virtual bool	isTransactional();
 		virtual void	setUser(const char *user);
 		virtual void	setPassword(const char *password);
 		virtual const char	*getUser();
 		virtual const char	*getPassword();
-		virtual void	dropTempTables(sqlrcursor *cursor,
+		virtual void	dropTempTables(sqlrcursor_svr *cursor,
 						stringlist *tablelist);
-		virtual void	dropTempTable(sqlrcursor *cursor,
+		virtual void	dropTempTable(sqlrcursor_svr *cursor,
 						const char *tablename);
-		virtual void	truncateTempTables(sqlrcursor *cursor,
+		virtual void	truncateTempTables(sqlrcursor_svr *cursor,
 						stringlist *tablelist);
-		virtual void	truncateTempTable(sqlrcursor *cursor,
+		virtual void	truncateTempTable(sqlrcursor_svr *cursor,
 						const char *tablename);
 
 	public:
@@ -87,43 +90,44 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		void		setAutoCommitBehavior(bool ac);
 		bool		getAutoCommitBehavior();
 		bool		sendColumnInfo();
-		void		sendRowCounts(long actual, long affected);
-		void		sendColumnCount(unsigned long ncols);
-		void		sendColumnTypeFormat(unsigned short format);
+		void		sendRowCounts(bool knowsactual,
+						uint64_t actual,
+						bool knowsaffected,
+						uint64_t affected);
 		void		sendColumnDefinition(const char *name, 
-						unsigned short namelen, 
-						unsigned short type, 
-						unsigned long size,
-						unsigned long precision,
-						unsigned long scale,
-						unsigned short nullable,
-						unsigned short primarykey,
-						unsigned short unique,
-						unsigned short partofkey,
-						unsigned short unsignednumber,
-						unsigned short zerofill,
-						unsigned short binary,
-						unsigned short autoincrement);
+						uint16_t namelen, 
+						uint16_t type, 
+						uint32_t size,
+						uint32_t precision,
+						uint32_t scale,
+						uint16_t nullable,
+						uint16_t primarykey,
+						uint16_t unique,
+						uint16_t partofkey,
+						uint16_t unsignednumber,
+						uint16_t zerofill,
+						uint16_t binary,
+						uint16_t autoincrement);
 		void		sendColumnDefinitionString(const char *name, 
-						unsigned short namelen, 
+						uint16_t namelen, 
 						const char *type, 
-						unsigned short typelen, 
-						unsigned long size,
-						unsigned long precision,
-						unsigned long scale,
-						unsigned short nullable,
-						unsigned short primarykey,
-						unsigned short unique,
-						unsigned short partofkey,
-						unsigned short unsignednumber,
-						unsigned short zerofill,
-						unsigned short binary,
-						unsigned short autoincrement);
-		void		sendField(const char *data, unsigned long size);
+						uint16_t typelen, 
+						uint32_t size,
+						uint32_t precision,
+						uint32_t scale,
+						uint16_t nullable,
+						uint16_t primarykey,
+						uint16_t unique,
+						uint16_t partofkey,
+						uint16_t unsignednumber,
+						uint16_t zerofill,
+						uint16_t binary,
+						uint16_t autoincrement);
+		void		sendField(const char *data, uint32_t size);
 		void		sendNullField();
-		void		startSendingLong(unsigned long length);
+		void		startSendingLong(uint64_t longlength);
 		void		sendLongSegment(const char *data,
-						unsigned long size);
+						uint32_t size);
 		void		endSendingLong();
 		void		addSessionTempTableForDrop(
 						const char *tablename);
@@ -133,6 +137,7 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 						const char *tablename);
 		void		addTransactionTempTableForTrunc(
 						const char *tablename);
+		void		abortAllCursors();
 
 	private:
 		// methods used internally
@@ -144,7 +149,7 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		void	announceAvailability(const char *tmpdir,
 					bool passdescriptor,
 					const char *unixsocket,
-					unsigned short inetport,
+					uint16_t inetport,
 					const char *connectionid);
 		void	registerForHandoff(const char *tmpdir);
 		bool	receiveFileDescriptor(int *descriptor);
@@ -170,22 +175,22 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		void		waitForListenerToFinishReading();
 		void		releaseAnnounceMutex();
 		void		acquireConnectionCountMutex();
-		unsigned int	*getConnectionCountBuffer();
+		uint32_t	*getConnectionCountBuffer();
 		void		signalScalerToRead();
 		void		releaseConnectionCountMutex();
 		void		acquireSessionCountMutex();
-		unsigned int	*getSessionCountBuffer();
+		uint32_t	*getSessionCountBuffer();
 		void		releaseSessionCountMutex();
 
 
-		sqlrcursor	*getCursor(unsigned short command);
-		sqlrcursor	*findAvailableCursor();
+		sqlrcursor_svr	*getCursor(uint16_t command);
+		sqlrcursor_svr	*findAvailableCursor();
 		void	closeCursors(bool destroy);
 		void	setUnixSocketDirectory();
 		bool	handlePidFile();
 		void	reLogIn();
 		void	initSession();
-		int	waitForClient();
+		int32_t	waitForClient();
 		void	clientSession();
 		bool	authenticateCommand();
 		void	suspendSessionCommand();
@@ -195,13 +200,13 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		void	autoCommitCommand();
 		void	commitCommand();
 		void	rollbackCommand();
-		bool	newQueryCommand(sqlrcursor *cursor);
-		bool	reExecuteQueryCommand(sqlrcursor *cursor);
-		bool	fetchFromBindCursorCommand(sqlrcursor *cursor);
-		bool	fetchResultSetCommand(sqlrcursor *cursor);
-		void	abortResultSetCommand(sqlrcursor *cursor);
-		void	suspendResultSetCommand(sqlrcursor *cursor);
-		bool	resumeResultSetCommand(sqlrcursor *cursor);
+		bool	newQueryCommand(sqlrcursor_svr *cursor);
+		bool	reExecuteQueryCommand(sqlrcursor_svr *cursor);
+		bool	fetchFromBindCursorCommand(sqlrcursor_svr *cursor);
+		bool	fetchResultSetCommand(sqlrcursor_svr *cursor);
+		void	abortResultSetCommand(sqlrcursor_svr *cursor);
+		void	suspendResultSetCommand(sqlrcursor_svr *cursor);
+		bool	resumeResultSetCommand(sqlrcursor_svr *cursor);
 		void	waitForClientClose();
 		void	closeSuspendedSessionSockets();
 		bool	authenticate();
@@ -211,45 +216,42 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 						const char *passwordbuffer);
 		bool	databaseBasedAuth(const char *userbuffer,
 						const char *passwordbuffer);
-		int	handleQuery(sqlrcursor *cursor,
+		int32_t	handleQuery(sqlrcursor_svr *cursor,
 					bool reexecute,
 					bool bindcursor,
 					bool reallyexecute);
-		bool	getQueryFromClient(sqlrcursor *cursor,
+		bool	getQueryFromClient(sqlrcursor_svr *cursor,
 						bool reexecute,
 						bool bindcursor);
-		void	resumeResultSet(sqlrcursor *cursor);
+		void	resumeResultSet(sqlrcursor_svr *cursor);
 		void	suspendSession();
 		void	endSession();
-		bool	getCommand(unsigned short *command);
-		void	noAvailableCursors(unsigned short command);
-		bool	getQuery(sqlrcursor *cursor);
-		bool	getInputBinds(sqlrcursor *cursor);
-		bool	getOutputBinds(sqlrcursor *cursor);
-		bool	getBindVarCount(unsigned short *count);
-		bool	getBindVarName(bindvar *bv);
-		bool	getBindVarType(bindvar *bv);
-		void	getNullBind(bindvar *bv);
-		bool	getBindSize(bindvar *bv, unsigned long maxsize);
-		bool	getStringBind(bindvar *bv);
-		bool	getLongBind(bindvar *bv);
-		bool	getDoubleBind(bindvar *bv);
-		bool	getLobBind(bindvar *bv);
+		bool	getCommand(uint16_t *command);
+		void	noAvailableCursors(uint16_t command);
+		bool	getQuery(sqlrcursor_svr *cursor);
+		bool	getInputBinds(sqlrcursor_svr *cursor);
+		bool	getOutputBinds(sqlrcursor_svr *cursor);
+		bool	getBindVarCount(uint16_t *count);
+		bool	getBindVarName(bindvar_svr *bv);
+		bool	getBindVarType(bindvar_svr *bv);
+		void	getNullBind(bindvar_svr *bv);
+		bool	getBindSize(bindvar_svr *bv, uint32_t maxsize);
+		bool	getStringBind(bindvar_svr *bv);
+		bool	getIntegerBind(bindvar_svr *bv);
+		bool	getDoubleBind(bindvar_svr *bv);
+		bool	getLobBind(bindvar_svr *bv);
 		bool	getSendColumnInfo();
-		bool	processQuery(sqlrcursor *cursor,
+		bool	processQuery(sqlrcursor_svr *cursor,
 						bool reexecute,
 						bool bindcursor,
 						bool reallyexecute);
-		void	commitOrRollback(sqlrcursor *cursor);
-		bool	handleError(sqlrcursor *cursor);
-		bool	returnError(sqlrcursor *cursor);
+		void	commitOrRollback(sqlrcursor_svr *cursor);
+		bool	handleError(sqlrcursor_svr *cursor);
+		bool	returnError(sqlrcursor_svr *cursor);
 		void	returnResultSet();
-		void	returnOutputBindValues(sqlrcursor *cursor);
-		void	returnResultSetHeader(sqlrcursor *cursor);
-		bool	returnResultSetData(sqlrcursor *cursor);
-
-		long	rowsToFetch();
-		long	rowsToSkip();
+		void	returnOutputBindValues(sqlrcursor_svr *cursor);
+		void	returnResultSetHeader(sqlrcursor_svr *cursor);
+		bool	returnResultSetData(sqlrcursor_svr *cursor);
 
 		void	initDatabaseAvailableFileName();
 		void	waitForAvailableDatabase();
@@ -264,9 +266,6 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 
 		void	flushWriteBuffer();
 
-		cmdline			*cmdl;
-		sqlrconfigfile		*cfgfl;
-
 		char			*user;
 		char			*password;
 
@@ -276,11 +275,11 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 
 		char		*updown;
 
-		unsigned short	inetport;
+		uint16_t	inetport;
 		char		*unixsocket;
 		char		*unixsocketptr;
 
-		unsigned short	sendcolumninfo;
+		uint16_t	sendcolumninfo;
 
 		authenticator	*authc;
 
@@ -295,17 +294,19 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		bool		autocommit;
 		bool		checkautocommit;
 		bool		performautocommit;
-		long		accepttimeout;
+		int32_t		accepttimeout;
 		bool		suspendedsession;
-		long		lastrow;
+		bool		lastrowvalid;
+		uint64_t	lastrow;
 
-		inetserversocket	*serversockin;
+		inetserversocket	**serversockin;
+		uint64_t		serversockincount;
 		unixserversocket	*serversockun;
 		filedescriptor		*clientsock;
 
 		memorypool	*bindpool;
 
-		sqlrcursor	**cur;
+		sqlrcursor_svr	**cur;
 
 		stringlist	sessiontemptablesfordrop;
 		stringlist	sessiontemptablesfortrunc;
@@ -316,15 +317,24 @@ class sqlrconnection : public daemonprocess, public listener, public debugfile {
 		bool			connected;
 
 		const char	*connectionid;
-		int		ttl;
+		unsigned int	ttl;
 
 		semaphoreset	*semset;
 		sharedmemory	*idmemory;
 
+		sqlrconnection	*sid_sqlrcon;
+
+		char		*pidfile;
+
 	protected:
 
-		unsigned long	stringbindvaluelength;
-		unsigned long	lobbindvaluelength;
+		cmdline			*cmdl;
+		sqlrconfigfile		*cfgfl;
+
+		uint32_t	maxquerysize;
+		uint32_t	maxstringbindvaluelength;
+		uint32_t	maxlobbindvaluelength;
+		int32_t		idleclienttimeout;
 
 #ifdef SERVER_DEBUG
 		stringbuffer	*debugstr;
