@@ -11,7 +11,9 @@
 #define MAX_ITEM_BUFFER_SIZE	4096
 #define MAX_BIND_VARS		512
 
-#define NUM_CONNECT_STRING_VARS 11
+//#define FREETDS_SUPPORTS_CURSORS
+
+#define NUM_CONNECT_STRING_VARS 10
 
 #include <rudiments/environment.h>
 #include <sqlrconnection.h>
@@ -22,38 +24,56 @@ extern "C" {
 
 class freetdsconnection;
 
-class freetdscursor : public sqlrcursor {
+class freetdscursor : public sqlrcursor_svr {
 	friend class freetdsconnection;
 	private:
-				freetdscursor(sqlrconnection *conn);
+				freetdscursor(sqlrconnection_svr *conn);
 				~freetdscursor();
-		bool		openCursor(int id);
+		bool		openCursor(uint16_t id);
 		bool		closeCursor();
-		bool		prepareQuery(const char *query, long length);
-		/*bool		inputBindString(const char *variable,
-						unsigned short variablesize,
+		bool		prepareQuery(const char *query,
+						uint32_t length);
+#ifdef FREETDS_SUPPORTS_CURSORS
+		bool		inputBindString(const char *variable,
+						uint16_t variablesize,
 						const char *value,
-						unsigned short valuesize,
-						short *isnull);
-		bool		inputBindLong(const char *variable,
-						unsigned short variablesize,
-						unsigned long *value);
+						uint16_t valuesize,
+						int16_t *isnull);
+		bool		inputBindInteger(const char *variable, 
+						uint16_t variablesize,
+						int64_t *value);
 		bool		inputBindDouble(const char *variable,
-						unsigned short variablesize,
+						uint16_t variablesize,
 						double *value,
-						unsigned short precision,
-						unsigned short scale);
+						uint32_t precision,
+						uint32_t scale);
 		bool		outputBindString(const char *variable, 
-						unsigned short variablesize,
+						uint16_t variablesize,
 						char *value, 
-						unsigned short valuesize, 
-						short *isnull);*/
+						uint16_t valuesize, 
+						int16_t *isnull);
+		bool		outputBindInteger(const char *variable,
+						uint16_t variablesize,
+						int64_t *value,
+						int16_t *isnull);
+		bool		outputBindDouble(const char *variable,
+						uint16_t variablesize,
+						double *value,
+						uint32_t *precision,
+						uint32_t *scale,
+						int16_t *isnull);
+#endif
 		bool		executeQuery(const char *query,
-						long length,
+						uint32_t length,
 						bool execute);
-		const char	*getErrorMessage(bool *liveconnection);
-		void		returnRowCounts();
-		void		returnColumnCount();
+		const char	*errorMessage(bool *liveconnection);
+		bool		knowsRowCount();
+		uint64_t	rowCount();
+		bool		knowsAffectedRows();
+		uint64_t	affectedRows();
+		uint32_t	colCount();
+		const char * const * columnNames();
+		uint16_t	columnTypeFormat();
 		void		returnColumnInfo();
 		bool		noRowsToReturn();
 		bool		skipRow();
@@ -67,9 +87,9 @@ class freetdscursor : public sqlrcursor {
 
 		void	checkRePrepare();
 
-		long	majorversion;
-		long	minorversion;
-		long	patchlevel;
+		uint32_t	majorversion;
+		uint32_t	minorversion;
+		uint32_t	patchlevel;
 
 		CS_COMMAND	*languagecmd;
 		CS_COMMAND	*cursorcmd;
@@ -77,20 +97,25 @@ class freetdscursor : public sqlrcursor {
 		CS_INT		results;
 		CS_INT		resultstype;
 		CS_INT		ncols;
+		bool		knowsaffectedrows;
 		CS_INT		affectedrows;
 
 		CS_INT		rowsread;
-		int		row;
-		int		maxrow;
-		int		totalrows;
+		CS_INT		row;
+		CS_INT		maxrow;
+		CS_INT		totalrows;
 
 		CS_DATAFMT	parameter[MAX_BIND_VARS];
-		int		paramindex;
-		char		*outbindvalues[MAX_BIND_VARS];
-		unsigned short	outbindvaluelengths[MAX_BIND_VARS];
-		int		outbindindex;
+		uint16_t	paramindex;
+		CS_INT		outbindtype[MAX_BIND_VARS];
+		char		*outbindstrings[MAX_BIND_VARS];
+		uint16_t	outbindstringlengths[MAX_BIND_VARS];
+		int64_t		*outbindints[MAX_BIND_VARS];
+		double		*outbinddoubles[MAX_BIND_VARS];
+		uint16_t	outbindindex;
 
 		CS_DATAFMT	column[MAX_SELECT_LIST_SIZE];
+		char		*columnnames[MAX_SELECT_LIST_SIZE];
 		char		data[MAX_SELECT_LIST_SIZE]
 					[FETCH_AT_ONCE]
 					[MAX_ITEM_BUFFER_SIZE];
@@ -100,7 +125,7 @@ class freetdscursor : public sqlrcursor {
 					[FETCH_AT_ONCE];
 
 		char		*query;
-		int		length;
+		uint32_t	length;
 		bool		prepared;
 		bool		clean;
 
@@ -109,25 +134,28 @@ class freetdscursor : public sqlrcursor {
 		bool			isrpcquery;
 
 		freetdsconnection	*freetdsconn;
+
+		unsigned short		opencount;
 };
 
 
-class freetdsconnection : public sqlrconnection {
+class freetdsconnection : public sqlrconnection_svr {
 	friend class freetdscursor;
 	public:
 			freetdsconnection();
 			~freetdsconnection();
 	private:
-		int	getNumberOfConnectStringVars();
+		uint16_t	getNumberOfConnectStringVars();
+		bool		supportsNativeBinds();
 		void	handleConnectString();
 		bool	logIn();
-		void	logInError(const char *error, int stage);
-		sqlrcursor	*initCursor();
-		void	deleteCursor(sqlrcursor *curs);
+		void	logInError(const char *error, uint16_t stage);
+		sqlrcursor_svr	*initCursor();
+		void	deleteCursor(sqlrcursor_svr *curs);
 		void	logOut();
 		const char	*identify();
 		char	bindVariablePrefix();
-		void	dropTempTable(sqlrcursor *cursor,
+		void	dropTempTable(sqlrcursor_svr *cursor,
 					const char *tablename);
 
 		CS_CONTEXT	*context;
@@ -140,8 +168,6 @@ class freetdsconnection : public sqlrconnection {
 		const char	*db;
 		const char	*charset;
 		const char	*language;
-		const char	*encryption;
-		int		enc;
 		const char	*hostname;
 		const char	*packetsize;
 
@@ -158,6 +184,9 @@ class freetdsconnection : public sqlrconnection {
 		static	CS_RETCODE	serverMessageCallback(CS_CONTEXT *ctxt,
 						CS_CONNECTION *cnn,
 						CS_SERVERMSG *msgp);
+
+		freetdscursor	*singlecursor;
+		unsigned short	singlecursorrefcount;
 };
 
 #endif
