@@ -33,61 +33,73 @@ struct fieldstruct {
 	short		nullindicator;
 };
 
-static char tpb[] = {
-	isc_tpb_version3,
-	isc_tpb_write,
-	isc_tpb_read_committed,
-	isc_tpb_rec_version,
-	// FIXME: vladimir changed this to isc_tpb_nowait.  why?
-	isc_tpb_wait
-};
-
 class interbaseconnection;
 
-class interbasecursor : public sqlrcursor {
+class interbasecursor : public sqlrcursor_svr {
 	friend class interbaseconnection;
 	private:
-				interbasecursor(sqlrconnection *conn);
+				interbasecursor(sqlrconnection_svr *conn);
 				~interbasecursor();
-		bool		prepareQuery(const char *query, long length);
+		bool		prepareQuery(const char *query,
+						uint32_t length);
 		bool		inputBindString(const char *variable, 
-						unsigned short variablesize,
+						uint16_t variablesize,
 						const char *value, 
-						unsigned short valuesize,
+						uint16_t valuesize,
 						short *isnull);
-		bool		inputBindLong(const char *variable, 
-						unsigned short variablesize,
-						unsigned long *value);
+		bool		inputBindInteger(const char *variable, 
+						uint16_t variablesize,
+						int64_t *value);
 		bool		inputBindDouble(const char *variable, 
-						unsigned short variablesize,
+						uint16_t variablesize,
 						double *value, 
-						unsigned short precision,
-						unsigned short scale);
+						uint32_t precision,
+						uint32_t scale);
 		bool		outputBindString(const char *variable, 
-						unsigned short variablesize,
+						uint16_t variablesize,
 						char *value, 
-						unsigned short valuesize,
+						uint16_t valuesize,
 						short *isnull);
+		bool		outputBindInteger(const char *variable,
+						uint16_t variablesize,
+						int64_t *value,
+						int16_t *isnull);
+		bool		outputBindDouble(const char *variable,
+						uint16_t variablesize,
+						double *value,
+						uint32_t *precision,
+						uint32_t *scale,
+						int16_t *isnull);
 		bool		executeQuery(const char *query,
-						long length,
+						uint32_t length,
 						bool execute);
 		bool		queryIsNotSelect();
 		bool		queryIsCommitOrRollback();
-		const char	*getErrorMessage(bool *liveconnection);
-		void		returnRowCounts();
-		void		returnColumnCount();
+		const char	*errorMessage(bool *liveconnection);
+		bool		knowsRowCount();
+		uint64_t	rowCount();
+		bool		knowsAffectedRows();
+		uint64_t	affectedRows();
+		uint32_t	colCount();
+		const char * const * columnNames();
+		uint16_t	columnTypeFormat();
 		void		returnColumnInfo();
 		bool		noRowsToReturn();
 		bool		skipRow();
 		bool		fetchRow();
 		void		returnRow();
+		void		cleanUpData(bool freeresult, bool freebinds);
+
 
 		isc_stmt_handle	stmt;
+		uint16_t	outbindcount;
+		bool		outbindisstring[MAXVAR];
 		XSQLDA	ISC_FAR	*outsqlda;
+		char		*columnnames[MAX_SELECT_LIST_SIZE];
 		XSQLDA	ISC_FAR	*insqlda;
 		ISC_BLOB_DESC	to_desc;
 
-		int		querytype;
+		ISC_LONG	querytype;
 
 		fieldstruct	field[MAX_SELECT_LIST_SIZE];
 
@@ -98,17 +110,17 @@ class interbasecursor : public sqlrcursor {
 		bool		queryIsExecSP;
 };
 
-class interbaseconnection : public sqlrconnection {
+class interbaseconnection : public sqlrconnection_svr {
 	friend class interbasecursor;
 	public:
 			interbaseconnection();
 			~interbaseconnection();
 	private:
-		int	getNumberOfConnectStringVars();
+		uint16_t	getNumberOfConnectStringVars();
 		void	handleConnectString();
 		bool	logIn();
-		sqlrcursor	*initCursor();
-		void	deleteCursor(sqlrcursor *curs);
+		sqlrcursor_svr	*initCursor();
+		void	deleteCursor(sqlrcursor_svr *curs);
 		void	logOut();
 		bool	commit();
 		bool	rollback();
@@ -121,7 +133,7 @@ class interbaseconnection : public sqlrconnection {
 		isc_tr_handle	tr;
 
 		const char	*database;
-		int		dialect;
+		unsigned short	dialect;
 
 		environment	*env;
 
