@@ -14,18 +14,24 @@ extern "C" {
 
 class mdbtoolsconnection;
 
-class mdbtoolscursor : public sqlrcursor {
+class mdbtoolscursor : public sqlrcursor_svr {
 	friend class mdbtoolsconnection;
 	private:
-				mdbtoolscursor(sqlrconnection *conn);
-		bool		openCursor(int id);
+				mdbtoolscursor(sqlrconnection_svr *conn);
+				~mdbtoolscursor();
+		bool		openCursor(uint16_t id);
 		bool		closeCursor();
 		bool		executeQuery(const char *query,
-						long length,
+						uint32_t length,
 						bool execute);
-		const char	*getErrorMessage(bool *liveconnection);
-		void		returnRowCounts();
-		void		returnColumnCount();
+		const char	*errorMessage(bool *liveconnection);
+		bool		knowsRowCount();
+		uint64_t	rowCount();
+		bool		knowsAffectedRows();
+		uint64_t	affectedRows();
+		uint32_t	colCount();
+		const char * const * columnNames();
+		uint16_t	columnTypeFormat();
 		void		returnColumnInfo();
 		bool		noRowsToReturn();
 		bool		skipRow();
@@ -35,19 +41,22 @@ class mdbtoolscursor : public sqlrcursor {
 
 		mdbtoolsconnection	*mdbtoolsconn;
 
+		char	**columnnames;
+
 		MdbSQL	mdbsql;
 };
 
-class mdbtoolsconnection : public sqlrconnection {
+class mdbtoolsconnection : public sqlrconnection_svr {
 	friend class mdbtoolscursor;
 	public:
 			mdbtoolsconnection();
 	private:
-		int	getNumberOfConnectStringVars();
+		uint16_t	getNumberOfConnectStringVars();
+		bool		supportsNativeBinds();
 		void	handleConnectString();
 		bool	logIn();
-		sqlrcursor	*initCursor();
-		void	deleteCursor(sqlrcursor *curs);
+		sqlrcursor_svr	*initCursor();
+		void	deleteCursor(sqlrcursor_svr *curs);
 		void	logOut();
 		bool	isTransactional();
 		bool	ping();
