@@ -12,16 +12,22 @@
 
 class msqlconnection;
 
-class msqlcursor : public sqlrcursor {
+class msqlcursor : public sqlrcursor_svr {
 	friend class msqlconnection;
 	private:
-				msqlcursor(sqlrconnection *conn);
+				msqlcursor(sqlrconnection_svr *conn);
+				~msqlcursor();
 		bool		executeQuery(const char *query,
-						long length,
+						uint32_t length,
 						bool execute);
-		const char	*getErrorMessage(bool *liveconnection);
-		void		returnRowCounts();
-		void		returnColumnCount();
+		const char	*errorMessage(bool *liveconnection);
+		bool		knowsRowCount();
+		uint64_t	rowCount();
+		bool		knowsAffectedRows();
+		uint64_t	affectedRows();
+		uint32_t	colCount();
+		const char * const * columnNames();
+		uint16_t	columnTypeFormat();
 		void		returnColumnInfo();
 		bool		noRowsToReturn();
 		bool		skipRow();
@@ -31,24 +37,25 @@ class msqlcursor : public sqlrcursor {
 
 		m_result	*msqlresult;
 		m_field		*msqlfield;
+		char		**columnnames;
 		m_row		msqlrow;
 		int		ncols;
 		int		nrows;
-		int		affectedrows;
 
 		msqlconnection	*msqlconn;
 };
 
-class msqlconnection : public sqlrconnection {
+class msqlconnection : public sqlrconnection_svr {
 	friend class msqlcursor;
 	public:
 			msqlconnection();
 	private:
-		int	getNumberOfConnectStringVars();
+		uint16_t	getNumberOfConnectStringVars();
+		bool		supportsNativeBinds();
 		void	handleConnectString();
 		bool	logIn();
-		sqlrcursor	*initCursor();
-		void	deleteCursor(sqlrcursor *curs);
+		sqlrcursor_svr	*initCursor();
+		void	deleteCursor(sqlrcursor_svr *curs);
 		void	logOut();
 		bool	isTransactional();
 		bool	ping();
