@@ -12,16 +12,22 @@
 
 class mysqlconnection;
 
-class mysqlcursor : public sqlrcursor {
+class mysqlcursor : public sqlrcursor_svr {
 	friend class mysqlconnection;
 	private:
-				mysqlcursor(sqlrconnection *conn);
+				mysqlcursor(sqlrconnection_svr *conn);
+				~mysqlcursor();
 		bool		executeQuery(const char *query,
-						long length,
+						uint32_t length,
 						bool execute);
-		const char	*getErrorMessage(bool *liveconnection);
-		void		returnRowCounts();
-		void		returnColumnCount();
+		const char	*errorMessage(bool *liveconnection);
+		bool		knowsRowCount();
+		uint64_t	rowCount();
+		bool		knowsAffectedRows();
+		uint64_t	affectedRows();
+		uint32_t	colCount();
+		const char * const * columnNames();
+		uint16_t	columnTypeFormat();
 		void		returnColumnInfo();
 		bool		noRowsToReturn();
 		bool		skipRow();
@@ -32,28 +38,31 @@ class mysqlcursor : public sqlrcursor {
 		MYSQL_RES	*mysqlresult;
 		MYSQL_FIELD	*mysqlfield;
 		MYSQL_ROW	mysqlrow;
-		int		ncols;
-		int		nrows;
-		int		affectedrows;
+		unsigned long	*mysqlrowlengths;
+		unsigned int	ncols;
+		my_ulonglong	nrows;
+		my_ulonglong	affectedrows;
 		int		queryresult;
+		char		**columnnames;
 
 		mysqlconnection	*mysqlconn;
 };
 
-class mysqlconnection : public sqlrconnection {
+class mysqlconnection : public sqlrconnection_svr {
 	friend class mysqlcursor;
 	public:
 				mysqlconnection();
 	private:
-		int		getNumberOfConnectStringVars();
+		uint16_t	getNumberOfConnectStringVars();
+		bool		supportsNativeBinds();
 		void		handleConnectString();
 		bool		logIn();
 #ifdef HAVE_MYSQL_CHANGE_USER
 		bool		changeUser(const char *newuser,
 						const char *newpassword);
 #endif
-		sqlrcursor	*initCursor();
-		void		deleteCursor(sqlrcursor *curs);
+		sqlrcursor_svr	*initCursor();
+		void		deleteCursor(sqlrcursor_svr *curs);
 		void		logOut();
 		bool		isTransactional();
 #ifdef HAVE_MYSQL_PING
@@ -66,7 +75,7 @@ class mysqlconnection : public sqlrconnection {
 		bool		rollback();
 
 		MYSQL	mysql;
-		int	connected;
+		bool	connected;
 
 		const char	*db;
 		const char	*host;
