@@ -6,17 +6,15 @@
 
 #define FETCH_AT_ONCE		10
 #define MAX_SELECT_LIST_SIZE	256
-#define MAX_ITEM_BUFFER_SIZE	4096
+#define MAX_ITEM_BUFFER_SIZE	32768
 
-#define MAX_STRING_BIND_VALUE_SIZE	32767
+#define NUM_CONNECT_STRING_VARS 6
 
-#define NUM_CONNECT_STRING_VARS 5
-
-#include <rudiments/environment.h>
 #include <sqlrconnection.h>
 #ifdef HAVE_ORACLE_8i
 	#include <rudiments/regularexpression.h>
 #endif
+#include <rudiments/environment.h>
 
 extern "C" {
 	#ifdef __CYGWIN__
@@ -55,82 +53,98 @@ struct describe {
 
 class oracle8connection;
 
-class oracle8cursor : public sqlrcursor {
+class oracle8cursor : public sqlrcursor_svr {
 	friend class oracle8connection;
 	private:
-				oracle8cursor(sqlrconnection *conn);
+				oracle8cursor(sqlrconnection_svr *conn);
 				~oracle8cursor();
-		bool		openCursor(int id);
+		bool		openCursor(uint16_t id);
 		bool		closeCursor();
-		bool		prepareQuery(const char *query, long length);
+		bool		prepareQuery(const char *query,
+						uint32_t length);
 		bool		inputBindString(const char *variable, 
-						unsigned short variablesize,
+						uint16_t variablesize,
 						const char *value, 
-						unsigned short valuesize,
-						short *isnull);
-		bool		inputBindLong(const char *variable, 
-						unsigned short variablesize,
-						unsigned long *value);
+						uint16_t valuesize,
+						int16_t *isnull);
+		bool		inputBindInteger(const char *variable, 
+						uint16_t variablesize,
+						int64_t *value);
 		bool		inputBindDouble(const char *variable, 
-						unsigned short variablesize,
+						uint16_t variablesize,
 						double *value,
-						unsigned short precision,
-						unsigned short scale);
+						uint32_t precision,
+						uint32_t scale);
 		bool		outputBindString(const char *variable, 
-						unsigned short variablesize,
+						uint16_t variablesize,
 						char *value,
-						unsigned short valuesize,
-						short *isnull);
+						uint16_t valuesize,
+						int16_t *isnull);
+		bool		outputBindInteger(const char *variable, 
+						uint16_t variablesize,
+						int64_t *value,
+						int16_t *isnull);
+		bool		outputBindDouble(const char *variable, 
+						uint16_t variablesize,
+						double *value,
+						uint32_t *precision,
+						uint32_t *scale,
+						int16_t *isnull);
 #ifdef HAVE_ORACLE_8i
 		bool		inputBindBlob(const char *variable, 
-						unsigned short variablesize,
+						uint16_t variablesize,
 						const char *value, 
-						unsigned long valuesize,
-						short *isnull);
+						uint32_t valuesize,
+						int16_t *isnull);
 		bool		inputBindClob(const char *variable, 
-						unsigned short variablesize,
+						uint16_t variablesize,
 						const char *value, 
-						unsigned long valuesize,
-						short *isnull);
+						uint32_t valuesize,
+						int16_t *isnull);
 		bool		inputBindGenericLob(const char *variable, 
-						unsigned short variablesize,
+						uint16_t variablesize,
 						const char *value, 
-						unsigned long valuesize,
-						short *isnull,
+						uint32_t valuesize,
+						int16_t *isnull,
 						ub1 temptype,
 						ub2 type);
 		bool		outputBindBlob(const char *variable, 
-						unsigned short variablesize,
-						int index,
-						short *isnull);
+						uint16_t variablesize,
+						uint16_t index,
+						int16_t *isnull);
 		bool		outputBindClob(const char *variable, 
-						unsigned short variablesize,
-						int index,
-						short *isnull);
+						uint16_t variablesize,
+						uint16_t index,
+						int16_t *isnull);
 		bool		outputBindGenericLob(const char *variable, 
-						unsigned short variablesize,
-						int index,
-						short *isnull,
+						uint16_t variablesize,
+						uint16_t index,
+						int16_t *isnull,
 						ub2 type);
 		bool		outputBindCursor(const char *variable,
-						unsigned short variablesize,
-						sqlrcursor *cursor);
-		void		returnOutputBindBlob(int index);
-		void		returnOutputBindClob(int index);
-		void		returnOutputBindGenericLob(int index);
+						uint16_t variablesize,
+						sqlrcursor_svr *cursor);
+		void		returnOutputBindBlob(uint16_t index);
+		void		returnOutputBindClob(uint16_t index);
+		void		sendLob(OCILobLocator *lob, ub1 *buf);
 #endif
 		bool		executeQuery(const char *query,
-						long length,
+						uint32_t length,
 						bool execute);
 #ifdef HAVE_ORACLE_8i
 		void		checkForTempTable(const char *query,
-							unsigned long length);
+							uint32_t length);
 #endif
 		bool		queryIsNotSelect();
 		bool		queryIsCommitOrRollback();
-		const char	*getErrorMessage(bool *liveconnection);
-		void		returnRowCounts();
-		void		returnColumnCount();
+		const char	*errorMessage(bool *liveconnection);
+		bool		knowsRowCount();
+		uint64_t	rowCount();
+		bool		knowsAffectedRows();
+		uint64_t	affectedRows();
+		uint32_t	colCount();
+		const char * const * columnNames();
+		uint16_t	columnTypeFormat();
 		void		returnColumnInfo();
 		bool		noRowsToReturn();
 		bool		skipRow();
@@ -145,40 +159,39 @@ class oracle8cursor : public sqlrcursor {
 		sword		ncols;
 		stringbuffer	*errormessage;
 
-		describe	desc[MAX_SELECT_LIST_SIZE];
-		OCIDefine	*def[MAX_SELECT_LIST_SIZE];
-		OCILobLocator	*def_lob[MAX_SELECT_LIST_SIZE][FETCH_AT_ONCE];
-		ub1		def_buf[MAX_SELECT_LIST_SIZE]
-					[FETCH_AT_ONCE][MAX_ITEM_BUFFER_SIZE];
-		sb2		def_indp[MAX_SELECT_LIST_SIZE][FETCH_AT_ONCE];
-		ub2		def_col_retlen[MAX_SELECT_LIST_SIZE]
-						[FETCH_AT_ONCE];
-		ub2		def_col_retcode[MAX_SELECT_LIST_SIZE]
-						[FETCH_AT_ONCE];
+		describe	*desc;
+		char		**columnnames;
+		OCIDefine	**def;
+		OCILobLocator	***def_lob;
+		ub1		**def_buf;
+		sb2		**def_indp;
+		ub2		**def_col_retlen;
+		ub2		**def_col_retcode;
 
 		OCIBind		*inbindpp[MAXVAR];
 		OCIBind		*outbindpp[MAXVAR];
 		OCIBind		*curbindpp[MAXVAR];
-		int		inbindcount;
-		int		outbindcount;
-		int		curbindcount;
+		char		*inintbindstring[MAXVAR];
+		char		*outintbindstring[MAXVAR];
+		int64_t		*outintbind[MAXVAR];
+		uint16_t	inbindcount;
+		uint16_t	outbindcount;
+		uint16_t	curbindcount;
 
 #ifdef HAVE_ORACLE_8i
 		OCILobLocator	*inbind_lob[MAXVAR];
 		OCILobLocator	*outbind_lob[MAXVAR];
-		int		inbindlobcount;
-		int		outbindlobcount;
+		uint16_t	inbindlobcount;
+		uint16_t	outbindlobcount;
 #endif
 
-		int		row;
-		int		maxrow;
-		unsigned int	totalrows;
-
-		int		fetchatonce;
+		uint64_t	row;
+		uint64_t	maxrow;
+		uint64_t	totalrows;
 
 		char		*query;
-		int		length;
-		int		prepared;
+		uint32_t	length;
+		bool		prepared;
 
 		oracle8connection	*oracle8conn;
 
@@ -187,18 +200,18 @@ class oracle8cursor : public sqlrcursor {
 #endif
 };
 	
-class oracle8connection : public sqlrconnection {
+class oracle8connection : public sqlrconnection_svr {
 	friend class oracle8cursor;
 	public:
 				oracle8connection();
 				~oracle8connection();
 	private:
-		int		getNumberOfConnectStringVars();
+		uint16_t	getNumberOfConnectStringVars();
 		void		handleConnectString();
 		bool		logIn();
 		void		logInError(const char *errmsg);
-		sqlrcursor	*initCursor();
-		void		deleteCursor(sqlrcursor *curs);
+		sqlrcursor_svr	*initCursor();
+		void		deleteCursor(sqlrcursor_svr *curs);
 		void		logOut();
 #ifdef OCI_ATTR_PROXY_CREDENTIALS
 		bool		changeUser(const char *newuser,
@@ -227,8 +240,13 @@ class oracle8connection : public sqlrconnection {
 
 		const char	*home;
 		const char	*sid;
+		const char	*nlslang;
 
-		environment	*environ;
+		ub4		fetchatonce;
+		ub4		maxselectlistsize;
+		ub4		maxitembuffersize;
+
+		environment	*envr;
 };
 
 #endif
