@@ -50,23 +50,19 @@ void checkSuccessInt(int value, int success) {
 
 int	main(int argc, char **argv) {
 
-	const char	*dbtype;
-	char	*subvars[4]={"var1","var2","var3",NULL};
-	char	*subvalstrings[3]={"hi","hello","bye"};
-	long	subvallongs[3]={1,2,3};
-	double	subvaldoubles[3]={10.55,10.556,10.5556};
-	unsigned short	precs[3]={4,5,6};
-	unsigned short	scales[3]={2,3,4};
-	const char	*numvar;
-	const char	*stringvar;
-	const char	*floatvar;
+	const char	*subvars[4]={"var1","var2","var3",NULL};
+	const char	*subvalstrings[3]={"hi","hello","bye"};
+	int64_t		subvallongs[3]={1,2,3};
+	double		subvaldoubles[3]={10.55,10.556,10.5556};
+	uint32_t	precs[3]={4,5,6};
+	uint32_t	scales[3]={2,3,4};
 	const char * const *cols;
 	const char * const *fields;
-	int	port;
+	uint16_t	port;
 	const char	*socket;
-	int	id;
-	const char	*filename;
-	long	*fieldlens;
+	uint16_t	id;
+	char		*filename;
+	uint32_t	*fieldlens;
 
 	// usage...
 	if (argc<5) {
@@ -108,7 +104,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("AFFECTED ROWS: \n");
-	checkSuccessInt(sqlrcur_affectedRows(cur),-1);
+	checkSuccessInt(sqlrcur_affectedRows(cur),1);
 	printf("\n");
 
 	printf("BIND BY POSITION: \n");
@@ -347,14 +343,14 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_getLongestByName(cur,"testtinyint"),1);
 	checkSuccessInt(sqlrcur_getLongestByIndex(cur,3),3);
 	checkSuccessInt(sqlrcur_getLongestByName(cur,"testreal"),3);
-	checkSuccessInt(sqlrcur_getLongestByIndex(cur,4),3);
-	checkSuccessInt(sqlrcur_getLongestByName(cur,"testfloat"),3);
-	checkSuccessInt(sqlrcur_getLongestByIndex(cur,5),3);
-	checkSuccessInt(sqlrcur_getLongestByName(cur,"testdecimal"),3);
-	checkSuccessInt(sqlrcur_getLongestByIndex(cur,6),3);
-	checkSuccessInt(sqlrcur_getLongestByName(cur,"testnumeric"),3);
-	checkSuccessInt(sqlrcur_getLongestByIndex(cur,7),6);
-	checkSuccessInt(sqlrcur_getLongestByName(cur,"testmoney"),6);
+	checkSuccessInt(sqlrcur_getLongestByIndex(cur,4),17);
+	checkSuccessInt(sqlrcur_getLongestByName(cur,"testfloat"),17);
+	checkSuccessInt(sqlrcur_getLongestByIndex(cur,5),17);
+	checkSuccessInt(sqlrcur_getLongestByName(cur,"testdecimal"),17);
+	checkSuccessInt(sqlrcur_getLongestByIndex(cur,6),17);
+	checkSuccessInt(sqlrcur_getLongestByName(cur,"testnumeric"),17);
+	checkSuccessInt(sqlrcur_getLongestByIndex(cur,7),4);
+	checkSuccessInt(sqlrcur_getLongestByName(cur,"testmoney"),4);
 	checkSuccessInt(sqlrcur_getLongestByIndex(cur,8),4);
 	checkSuccessInt(sqlrcur_getLongestByName(cur,"testsmallmoney"),4);
 	checkSuccessInt(sqlrcur_getLongestByIndex(cur,9),19);
@@ -374,7 +370,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("TOTAL ROWS: \n");
-	checkSuccessInt(sqlrcur_totalRows(cur),-1);
+	checkSuccessInt(sqlrcur_totalRows(cur),0);
 	printf("\n");
 
 	printf("FIRST ROW INDEX: \n");
@@ -393,10 +389,10 @@ int	main(int argc, char **argv) {
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,4),"1.1");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,5),"1.1");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,6),"1.1");
-	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,7),"1.0000");
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,7),"1.00");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,8),"1.00");
-	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,9),"Jan  1 2001  1:00AM");
-	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,10),"Jan  1 2001  1:00AM");
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,9),"Jan 01 2001 01:00AM");
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,10),"Jan 01 2001 01:00AM");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,11),"testchar1                               ");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,12),"testvarchar1");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,13),"1");
@@ -405,13 +401,13 @@ int	main(int argc, char **argv) {
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,1),"8");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,2),"8");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,3),"8.8");
-	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,4),"8.8");
-	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,5),"8.8");
-	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,6),"8.8");
-	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,7),"8.0000");
+	//checkSuccessString(sqlrcur_getFieldByIndex(cur,7,4),"8.8");
+	//checkSuccessString(sqlrcur_getFieldByIndex(cur,7,5),"8.8");
+	//checkSuccessString(sqlrcur_getFieldByIndex(cur,7,6),"8.8");
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,7),"8.00");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,8),"8.00");
-	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,9),"Jan  1 2008  8:00AM");
-	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,10),"Jan  1 2008  8:00AM");
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,9),"Jan 01 2008 08:00AM");
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,10),"Jan 01 2008 08:00AM");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,11),"testchar8                               ");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,12),"testvarchar8");
 	checkSuccessString(sqlrcur_getFieldByIndex(cur,7,13),"1");
@@ -425,7 +421,7 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,0,4),3);
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,0,5),3);
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,0,6),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,0,7),6);
+	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,0,7),4);
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,0,8),4);
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,0,9),19);
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,0,10),19);
@@ -437,10 +433,10 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,1),1);
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,2),1);
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,3),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,4),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,5),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,6),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,7),6);
+	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,4),17);
+	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,5),17);
+	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,6),17);
+	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,7),4);
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,8),4);
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,9),19);
 	checkSuccessInt(sqlrcur_getFieldLengthByIndex(cur,7,10),19);
@@ -457,10 +453,10 @@ int	main(int argc, char **argv) {
 	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testfloat"),"1.1");
 	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testdecimal"),"1.1");
 	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testnumeric"),"1.1");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testmoney"),"1.0000");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testmoney"),"1.00");
 	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testsmallmoney"),"1.00");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testdatetime"),"Jan  1 2001  1:00AM");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testsmalldatetime"),"Jan  1 2001  1:00AM");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testdatetime"),"Jan 01 2001 01:00AM");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testsmalldatetime"),"Jan 01 2001 01:00AM");
 	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testchar"),"testchar1                               ");
 	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testvarchar"),"testvarchar1");
 	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testbit"),"1");
@@ -469,13 +465,13 @@ int	main(int argc, char **argv) {
 	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testsmallint"),"8");
 	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testtinyint"),"8");
 	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testreal"),"8.8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testfloat"),"8.8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testdecimal"),"8.8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testnumeric"),"8.8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testmoney"),"8.0000");
+	//checkSuccessString(sqlrcur_getFieldByName(cur,7,"testfloat"),"8.8");
+	//checkSuccessString(sqlrcur_getFieldByName(cur,7,"testdecimal"),"8.8");
+	//checkSuccessString(sqlrcur_getFieldByName(cur,7,"testnumeric"),"8.8");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testmoney"),"8.00");
 	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testsmallmoney"),"8.00");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testdatetime"),"Jan  1 2008  8:00AM");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testsmalldatetime"),"Jan  1 2008  8:00AM");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testdatetime"),"Jan 01 2008 08:00AM");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testsmalldatetime"),"Jan 01 2008 08:00AM");
 	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testchar"),"testchar8                               ");
 	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testvarchar"),"testvarchar8");
 	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testbit"),"1");
@@ -489,7 +485,7 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testfloat"),3);
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testdecimal"),3);
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testnumeric"),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testmoney"),6);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testmoney"),4);
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testsmallmoney"),4);
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testdatetime"),19);
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testsmalldatetime"),19);
@@ -501,10 +497,10 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testsmallint"),1);
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testtinyint"),1);
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testreal"),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testfloat"),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testdecimal"),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testnumeric"),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testmoney"),6);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testfloat"),17);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testdecimal"),17);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testnumeric"),17);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testmoney"),4);
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testsmallmoney"),4);
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testdatetime"),19);
 	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testsmalldatetime"),19);
@@ -522,10 +518,10 @@ int	main(int argc, char **argv) {
 	checkSuccessString(fields[4],"1.1");
 	checkSuccessString(fields[5],"1.1");
 	checkSuccessString(fields[6],"1.1");
-	checkSuccessString(fields[7],"1.0000");
+	checkSuccessString(fields[7],"1.00");
 	checkSuccessString(fields[8],"1.00");
-	checkSuccessString(fields[9],"Jan  1 2001  1:00AM");
-	checkSuccessString(fields[10],"Jan  1 2001  1:00AM");
+	checkSuccessString(fields[9],"Jan 01 2001 01:00AM");
+	checkSuccessString(fields[10],"Jan 01 2001 01:00AM");
 	checkSuccessString(fields[11],"testchar1                               ");
 	checkSuccessString(fields[12],"testvarchar1");
 	checkSuccessString(fields[13],"1");
@@ -540,7 +536,7 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(fieldlens[4],3);
 	checkSuccessInt(fieldlens[5],3);
 	checkSuccessInt(fieldlens[6],3);
-	checkSuccessInt(fieldlens[7],6);
+	checkSuccessInt(fieldlens[7],4);
 	checkSuccessInt(fieldlens[8],4);
 	checkSuccessInt(fieldlens[9],19);
 	checkSuccessInt(fieldlens[10],19);
@@ -895,4 +891,5 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
 
+	exit(0);
 }
