@@ -51,23 +51,19 @@ void checkSuccessInt(int value, int success) {
 int	main(int argc, char **argv) {
 
 
-	const char	*dbtype;
-	char	*subvars[4]={"var1","var2","var3",NULL};
-	char	*subvalstrings[3]={"hi","hello","bye"};
-	long	subvallongs[3]={1,2,3};
-	double	subvaldoubles[3]={10.55,10.556,10.5556};
-	unsigned short	precs[3]={4,5,6};
-	unsigned short	scales[3]={2,3,4};
-	const char	*numvar;
-	const char	*stringvar;
-	const char	*floatvar;
+	const char	*subvars[4]={"var1","var2","var3",NULL};
+	const char	*subvalstrings[3]={"hi","hello","bye"};
+	int64_t		subvallongs[3]={1,2,3};
+	double		subvaldoubles[3]={10.55,10.556,10.5556};
+	uint32_t	precs[3]={4,5,6};
+	uint32_t	scales[3]={2,3,4};
 	const char * const *cols;
 	const char * const *fields;
-	int	port;
+	uint16_t	port;
 	const char	*socket;
-	int	id;
-	const char	*filename;
-	long	*fieldlens;
+	uint16_t	id;
+	char		*filename;
+	uint32_t	*fieldlens;
 
 
 	// usage...
@@ -107,7 +103,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("AFFECTED ROWS: \n");
-	checkSuccessInt(sqlrcur_affectedRows(cur),-1);
+	checkSuccessInt(sqlrcur_affectedRows(cur),0);
 	printf("\n");
 
 	printf("BIND BY NAME: \n");
@@ -731,4 +727,6 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
+
+	exit(0);
 }
