@@ -37,7 +37,8 @@ void checkSuccessString(const char *value, const char *success) {
 	}
 }
 
-void checkSuccessStringWithLength(char *value, char *success, int length) {
+void checkSuccessStringWithLength(const char *value, const char *success,
+								int length) {
 
 	if (!success) {
 		if (!value) {
@@ -73,38 +74,52 @@ void checkSuccessInt(int value, int success) {
 	}
 }
 
+void checkSuccessDouble(double value, double success) {
+
+	if (value==success) {
+		printf("success ");
+	} else {
+		printf("failure ");
+		sqlrcur_free(cur);
+		sqlrcon_free(con);
+		exit(0);
+	}
+}
+
 int	main(int argc, char **argv) {
 
-	const char	*dbtype;
-	char	*bindvars[6]={"1","2","3","4","5",NULL};
-	char	*bindvals[5]={"4","testchar4","testvarchar4","01-JAN-2004","testlong4"};
-	char	*subvars[4]={"var1","var2","var3",NULL};
-	char	*subvalstrings[3]={"hi","hello","bye"};
-	long	subvallongs[3]={1,2,3};
-	double	subvaldoubles[3]={10.55,10.556,10.5556};
-	unsigned short	precs[3]={4,5,6};
-	unsigned short	scales[3]={2,3,4};
-	const char	*numvar;
+	const char	*bindvars[6]={"1","2","3","4","5",NULL};
+	const char	*bindvals[5]={"4","testchar4","testvarchar4",
+						"01-JAN-2004","testlong4"};
+	const char	*subvars[4]={"var1","var2","var3",NULL};
+	const char	*subvalstrings[3]={"hi","hello","bye"};
+	int64_t		subvallongs[3]={1,2,3};
+	double		subvaldoubles[3]={10.55,10.556,10.5556};
+	uint32_t	precs[3]={4,5,6};
+	uint32_t	scales[3]={2,3,4};
+	int64_t		numvar;
 	const char	*clobvar;
 	char	clobval[8*1024+1];
 	long	clobvarlength;
 	const char	*blobvar;
 	long	blobvarlength;
 	const char	*stringvar;
-	const char	*floatvar;
+	double		floatvar;
 	const char * const *cols;
 	const char * const *fields;
-	int	port;
+	uint16_t	port;
 	const char	*socket;
-	int	id;
+	uint16_t	id;
 	char	*filename;
-	char	*arraybindvars[6]={"var1","var2","var3","var4","var5",NULL};
-	char	*arraybindvals[5]={"7","testchar7","testvarchar7","01-JAN-2007","testlong7"};
-	long	*fieldlens;
+	const char	*arraybindvars[6]={"var1","var2","var3",
+						"var4","var5",NULL};
+	const char	*arraybindvals[5]={"7","testchar7","testvarchar7",
+						"01-JAN-2007","testlong7"};
+	uint32_t	*fieldlens;
 	char	testval[4001];
 	int	i;
 	char	query[4000+25];
-	char	*clobbindvar;
+	const char	*clobbindvar;
 
 
 	// usage...
@@ -219,46 +234,46 @@ int	main(int argc, char **argv) {
 
 	printf("OUTPUT BIND BY NAME: \n");
 	sqlrcur_prepareQuery(cur,"begin  :numvar:=1; :stringvar:='hello'; :floatvar:=2.5; end;");
-	sqlrcur_defineOutputBind(cur,"numvar",10);
-	sqlrcur_defineOutputBind(cur,"stringvar",10);
-	sqlrcur_defineOutputBind(cur,"floatvar",10);
+	sqlrcur_defineOutputBindInteger(cur,"numvar");
+	sqlrcur_defineOutputBindString(cur,"stringvar",10);
+	sqlrcur_defineOutputBindDouble(cur,"floatvar");
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
-	numvar=sqlrcur_getOutputBind(cur,"numvar");
-	stringvar=sqlrcur_getOutputBind(cur,"stringvar");
-	floatvar=sqlrcur_getOutputBind(cur,"floatvar");
-	checkSuccessString(numvar,"1");
+	numvar=sqlrcur_getOutputBindInteger(cur,"numvar");
+	stringvar=sqlrcur_getOutputBindString(cur,"stringvar");
+	floatvar=sqlrcur_getOutputBindDouble(cur,"floatvar");
+	checkSuccessInt(numvar,1);
 	checkSuccessString(stringvar,"hello");
-	checkSuccessString(floatvar,"2.5");
+	checkSuccessDouble(floatvar,2.5);
 	printf("\n");
 
-	printf("OUTPUT BIND BY NAME: \n");
+	printf("OUTPUT BIND BY POSITION: \n");
 	sqlrcur_clearBinds(cur);
-	sqlrcur_defineOutputBind(cur,"1",10);
-	sqlrcur_defineOutputBind(cur,"2",10);
-	sqlrcur_defineOutputBind(cur,"3",10);
+	sqlrcur_defineOutputBindInteger(cur,"1");
+	sqlrcur_defineOutputBindString(cur,"2",10);
+	sqlrcur_defineOutputBindDouble(cur,"3");
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
-	numvar=sqlrcur_getOutputBind(cur,"1");
-	stringvar=sqlrcur_getOutputBind(cur,"2");
-	floatvar=sqlrcur_getOutputBind(cur,"3");
-	checkSuccessString(numvar,"1");
+	numvar=sqlrcur_getOutputBindInteger(cur,"1");
+	stringvar=sqlrcur_getOutputBindString(cur,"2");
+	floatvar=sqlrcur_getOutputBindDouble(cur,"3");
+	checkSuccessInt(numvar,1);
 	checkSuccessString(stringvar,"hello");
-	checkSuccessString(floatvar,"2.5");
+	checkSuccessDouble(floatvar,2.5);
 	printf("\n");
 
 	printf("OUTPUT BIND BY NAME WITH VALIDATION: \n");
 	sqlrcur_clearBinds(cur);
-	sqlrcur_defineOutputBind(cur,"numvar",10);
-	sqlrcur_defineOutputBind(cur,"stringvar",10);
-	sqlrcur_defineOutputBind(cur,"floatvar",10);
-	sqlrcur_defineOutputBind(cur,"dummyvar",10);
+	sqlrcur_defineOutputBindInteger(cur,"numvar");
+	sqlrcur_defineOutputBindString(cur,"stringvar",10);
+	sqlrcur_defineOutputBindDouble(cur,"floatvar");
+	sqlrcur_defineOutputBindString(cur,"dummyvar",10);
 	sqlrcur_validateBinds(cur);
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
-	numvar=sqlrcur_getOutputBind(cur,"numvar");
-	stringvar=sqlrcur_getOutputBind(cur,"stringvar");
-	floatvar=sqlrcur_getOutputBind(cur,"floatvar");
-	checkSuccessString(numvar,"1");
+	numvar=sqlrcur_getOutputBindInteger(cur,"numvar");
+	stringvar=sqlrcur_getOutputBindString(cur,"stringvar");
+	floatvar=sqlrcur_getOutputBindDouble(cur,"floatvar");
+	checkSuccessInt(numvar,1);
 	checkSuccessString(stringvar,"hello");
-	checkSuccessString(floatvar,"2.5");
+	checkSuccessDouble(floatvar,2.5);
 	printf("\n");
 
 	printf("SELECT: \n");
@@ -343,7 +358,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("TOTAL ROWS: \n");
-	checkSuccessInt(sqlrcur_totalRows(cur),-1);
+	checkSuccessInt(sqlrcur_totalRows(cur),0);
 	printf("\n");
 
 	printf("FIRST ROW INDEX: \n");
@@ -464,9 +479,9 @@ int	main(int argc, char **argv) {
 
 	printf("OUTPUT BIND: \n");
 	sqlrcur_prepareQuery(cur,"begin :var1:='hello'; end;");
-	sqlrcur_defineOutputBind(cur,"var1",10);
+	sqlrcur_defineOutputBindString(cur,"var1",10);
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
-	checkSuccessString(sqlrcur_getOutputBind(cur,"var1"),"hello");
+	checkSuccessString(sqlrcur_getOutputBindString(cur,"var1"),"hello");
 	printf("\n");
 
 	printf("ARRAY SUBSTITUTIONS: \n");
@@ -774,9 +789,9 @@ int	main(int argc, char **argv) {
 	sqlrcur_defineOutputBindClob(cur,"clobvar");
 	sqlrcur_defineOutputBindBlob(cur,"blobvar");
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
-	clobvar=sqlrcur_getOutputBind(cur,"clobvar");
+	clobvar=sqlrcur_getOutputBindClob(cur,"clobvar");
 	clobvarlength=sqlrcur_getOutputBindLength(cur,"clobvar");
-	blobvar=sqlrcur_getOutputBind(cur,"blobvar");
+	blobvar=sqlrcur_getOutputBindBlob(cur,"blobvar");
 	blobvarlength=sqlrcur_getOutputBindLength(cur,"blobvar");
 	checkSuccessStringWithLength(clobvar,"hello",5);
 	checkSuccessInt(clobvarlength,5);
@@ -836,7 +851,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_prepareQuery(cur,"begin select testclob into :clobbindval from testtable2; end;");
 	sqlrcur_defineOutputBindClob(cur,"clobbindval");
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
-	clobbindvar=sqlrcur_getOutputBind(cur,"clobbindval");
+	clobbindvar=sqlrcur_getOutputBindClob(cur,"clobbindval");
 	checkSuccessInt(sqlrcur_getOutputBindLength(cur,"clobbindval"),8*1024);
 	checkSuccessString(clobval,clobbindvar);
 	sqlrcur_sendQuery(cur,"drop table testtable2");
@@ -857,10 +872,10 @@ int	main(int argc, char **argv) {
 	checkSuccessString(testval,sqlrcur_getFieldByName(cur,0,"testval"));
 	sprintf(query,"begin :bindval:='%s'; end;",testval);
 	sqlrcur_prepareQuery(cur,query);
-	sqlrcur_defineOutputBind(cur,"bindval",4000);
+	sqlrcur_defineOutputBindString(cur,"bindval",4000);
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
 	checkSuccessInt(sqlrcur_getOutputBindLength(cur,"bindval"),4000);
-	checkSuccessString(sqlrcur_getOutputBind(cur,"bindval"),testval);
+	checkSuccessString(sqlrcur_getOutputBindString(cur,"bindval"),testval);
 	sqlrcur_sendQuery(cur,"drop table testtable2");
 	printf("\n");
 
@@ -914,4 +929,5 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
 
+	exit(0);
 }
