@@ -50,23 +50,19 @@ void checkSuccessInt(int value, int success) {
 
 int	main(int argc, char **argv) {
 
-	const char	*dbtype;
-	char	*subvars[4]={"var1","var2","var3",NULL};
-	char	*subvalstrings[3]={"hi","hello","bye"};
-	long	subvallongs[3]={1,2,3};
-	double	subvaldoubles[3]={10.55,10.556,10.5556};
-	unsigned short	precs[3]={4,5,6};
-	unsigned short	scales[3]={2,3,4};
-	const char	*numvar;
-	const char	*stringvar;
-	const char	*floatvar;
+	const char	*subvars[4]={"var1","var2","var3",NULL};
+	const char	*subvalstrings[3]={"hi","hello","bye"};
+	int64_t		subvallongs[3]={1,2,3};
+	double		subvaldoubles[3]={10.55,10.556,10.5556};
+	uint32_t	precs[3]={4,5,6};
+	uint32_t	scales[3]={2,3,4};
 	const char * const *cols;
 	const char * const *fields;
-	int	port;
+	uint16_t	port;
 	const char	*socket;
-	int	id;
+	uint16_t	id;
 	const char	*filename;
-	long	*fieldlens;
+	uint32_t	*fieldlens;
 
 	// usage...
 	if (argc<5) {
@@ -110,7 +106,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("AFFECTED ROWS: \n");
-	checkSuccessInt(sqlrcur_affectedRows(cur),-1);
+	checkSuccessInt(sqlrcur_affectedRows(cur),0);
 	printf("\n");
 
 	printf("BIND BY NAME: \n");
@@ -583,7 +579,8 @@ int	main(int argc, char **argv) {
 				atoi(argv[2]), 
 				argv[3],argv[4],argv[5],0,1);
 	secondcur=sqlrcur_alloc(secondcon);
-	checkSuccessInt(sqlrcur_sendQuery(secondcur,"select count(*) from testtable"),0);
+	checkSuccessInt(sqlrcur_sendQuery(secondcur,"select count(*) from testtable"),1);
+	checkSuccessString(sqlrcur_getFieldByIndex(secondcur,0,0),"0");
 	checkSuccessInt(sqlrcon_commit(con),1);
 	checkSuccessInt(sqlrcur_sendQuery(secondcur,"select count(*) from testtable"),1);
 	checkSuccessString(sqlrcur_getFieldByIndex(secondcur,0,0),"8");
@@ -632,4 +629,5 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
 
+	exit(0);
 }
