@@ -51,39 +51,27 @@ void checkSuccessInt(int value, int success) {
 
 int	main(int argc, char **argv) {
 
-	const char	*dbtype;
-	char	*bindvars[14]={"1","2","3","4","5","6",
+	const char	*bindvars[14]={"1","2","3","4","5","6",
 				"7","8","9","10","11","12",
 				"13",NULL};
-	char	*bindvals[13]={"4","4","4","4.4","4.4","4.4","4.4",
+	const char	*bindvals[13]={"4","4","4","4.4","4.4","4.4","4.4",
 				"4.00","4.00",
 				"01-Jan-2004 04:00:00",
 				"01-Jan-2004 04:00:00",
 				"testchar4","testvarchar4"};
-	char	*arraybindvars[14]={"var1","var2","var3","var4","var5","var6",
-				"var7","var8","var9","var10","var11","var12",
-				"var13",NULL};
-	char	*arraybindvals[13]={"7","7","7","7.7","7.7","7.7","7.7",
-				"7.00","7.00",
-				"01-Jan-2007 07:00:00",
-				"01-Jan-2007 07:00:00",
-				"testchar7","testvarchar7"};
-	char	*subvars[4]={"var1","var2","var3",NULL};
-	char	*subvalstrings[3]={"hi","hello","bye"};
-	long	subvallongs[3]={1,2,3};
-	double	subvaldoubles[3]={10.55,10.556,10.5556};
-	unsigned short	precs[3]={4,5,6};
-	unsigned short	scales[3]={2,3,4};
-	const char	*numvar;
-	const char	*stringvar;
-	const char	*floatvar;
+	const char	*subvars[4]={"var1","var2","var3",NULL};
+	const char	*subvalstrings[3]={"hi","hello","bye"};
+	int64_t		subvallongs[3]={1,2,3};
+	double		subvaldoubles[3]={10.55,10.556,10.5556};
+	uint32_t	precs[3]={4,5,6};
+	uint32_t	scales[3]={2,3,4};
 	const char * const *cols;
 	const char * const *fields;
-	int	port;
+	uint16_t	port;
 	const char	*socket;
-	int	id;
-	const char	*filename;
-	long	*fieldlens;
+	uint16_t	id;
+	char		*filename;
+	uint32_t	*fieldlens;
 
 	// usage...
 	if (argc<5) {
@@ -388,7 +376,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("TOTAL ROWS: \n");
-	checkSuccessInt(sqlrcur_totalRows(cur),-1);
+	checkSuccessInt(sqlrcur_totalRows(cur),0);
 	printf("\n");
 
 	printf("FIRST ROW INDEX: \n");
@@ -908,4 +896,5 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
 
+	exit(0);
 }
