@@ -74,9 +74,9 @@ class mysql {
 		String	floatvar;
 		String[]	cols;
 		String[]	fields;
-		int	port;
+		short	port;
 		String	socket;
-		int	id;
+		short	id;
 		String	filename;
 		long[]	fieldlens;
 	
@@ -89,7 +89,8 @@ class mysql {
 	
 	
 		// instantiation
-		SQLRConnection con=new SQLRConnection(args[0],Integer.parseInt(args[1]), 
+		SQLRConnection con=new SQLRConnection(args[0],
+					(short)Integer.parseInt(args[1]), 
 						args[2],args[3],args[4],0,1);
 		SQLRCursor cur=new SQLRCursor(con);
 	
@@ -276,8 +277,8 @@ class mysql {
 		checkSuccess(cur.getColumnType(13),"BLOB");
 		checkSuccess(cur.getColumnType(14),"CHAR");
 		checkSuccess(cur.getColumnType(15),"TINYBLOB");
-		checkSuccess(cur.getColumnType(16),"BLOB");
-		checkSuccess(cur.getColumnType(17),"BLOB");
+		checkSuccess(cur.getColumnType(16),"MEDIUMBLOB");
+		checkSuccess(cur.getColumnType(17),"LONGBLOB");
 		checkSuccess(cur.getColumnType(18),"TIMESTAMP");
 		checkSuccess(cur.getColumnType("testtinyint"),"TINYINT");
 		checkSuccess(cur.getColumnType("testsmallint"),"SMALLINT");
@@ -295,8 +296,8 @@ class mysql {
 		checkSuccess(cur.getColumnType("testtext"),"BLOB");
 		checkSuccess(cur.getColumnType("testvarchar"),"CHAR");
 		checkSuccess(cur.getColumnType("testtinytext"),"TINYBLOB");
-		checkSuccess(cur.getColumnType("testmediumtext"),"BLOB");
-		checkSuccess(cur.getColumnType("testlongtext"),"BLOB");
+		checkSuccess(cur.getColumnType("testmediumtext"),"MEDIUMBLOB");
+		checkSuccess(cur.getColumnType("testlongtext"),"LONGBLOB");
 		checkSuccess(cur.getColumnType("testtimestamp"),"TIMESTAMP");
 		System.out.println();
 	
@@ -314,11 +315,11 @@ class mysql {
 		checkSuccess(cur.getColumnLength(10),8);
 		checkSuccess(cur.getColumnLength(11),1);
 		checkSuccess(cur.getColumnLength(12),41);
-		checkSuccess(cur.getColumnLength(13),65538);
+		checkSuccess(cur.getColumnLength(13),65535);
 		checkSuccess(cur.getColumnLength(14),41);
-		checkSuccess(cur.getColumnLength(15),257);
-		checkSuccess(cur.getColumnLength(16),16777218);
-		checkSuccess(cur.getColumnLength(17),16777218);
+		checkSuccess(cur.getColumnLength(15),255);
+		checkSuccess(cur.getColumnLength(16),16777215);
+		checkSuccess(cur.getColumnLength(17),2147483647);
 		checkSuccess(cur.getColumnLength(18),4);
 		checkSuccess(cur.getColumnLength("testtinyint"),1);
 		checkSuccess(cur.getColumnLength("testsmallint"),2);
@@ -333,11 +334,11 @@ class mysql {
 		checkSuccess(cur.getColumnLength("testdatetime"),8);
 		checkSuccess(cur.getColumnLength("testyear"),1);
 		checkSuccess(cur.getColumnLength("testchar"),41);
-		checkSuccess(cur.getColumnLength("testtext"),65538);
+		checkSuccess(cur.getColumnLength("testtext"),65535);
 		checkSuccess(cur.getColumnLength("testvarchar"),41);
-		checkSuccess(cur.getColumnLength("testtinytext"),257);
-		checkSuccess(cur.getColumnLength("testmediumtext"),16777218);
-		checkSuccess(cur.getColumnLength("testlongtext"),16777218);
+		checkSuccess(cur.getColumnLength("testtinytext"),255);
+		checkSuccess(cur.getColumnLength("testmediumtext"),16777215);
+		checkSuccess(cur.getColumnLength("testlongtext"),2147483647);
 		checkSuccess(cur.getColumnLength("testtimestamp"),4);
 		System.out.println();
 	
@@ -360,7 +361,7 @@ class mysql {
 		checkSuccess(cur.getLongest(15),9);
 		checkSuccess(cur.getLongest(16),11);
 		checkSuccess(cur.getLongest(17),9);
-		checkSuccess(cur.getLongest(18),14);
+		checkSuccess(cur.getLongest(18),19);
 		checkSuccess(cur.getLongest("testtinyint"),1);
 		checkSuccess(cur.getLongest("testsmallint"),1);
 		checkSuccess(cur.getLongest("testmediumint"),1);
@@ -379,7 +380,7 @@ class mysql {
 		checkSuccess(cur.getLongest("testtinytext"),9);
 		checkSuccess(cur.getLongest("testmediumtext"),11);
 		checkSuccess(cur.getLongest("testlongtext"),9);
-		checkSuccess(cur.getLongest("testtimestamp"),14);
+		checkSuccess(cur.getLongest("testtimestamp"),19);
 		System.out.println();
 	
 		System.out.println("ROW COUNT: ");
@@ -915,7 +916,8 @@ class mysql {
 		System.out.println();
 	
 		System.out.println("COMMIT AND ROLLBACK: ");
-		SQLRConnection secondcon=new SQLRConnection(args[0],Integer.parseInt(args[1]), 
+		SQLRConnection secondcon=new SQLRConnection(args[0],
+					(short)Integer.parseInt(args[1]), 
 						args[2],args[3],args[4],0,1);
 		SQLRCursor secondcur=new SQLRCursor(secondcon);
 		checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
