@@ -74,9 +74,9 @@ class sqlite {
 		String	floatvar;
 		String[]	cols;
 		String[]	fields;
-		int	port;
+		short	port;
 		String	socket;
-		int	id;
+		short	id;
 		String	filename;
 		long[]	fieldlens;
 	
@@ -87,7 +87,8 @@ class sqlite {
 		}
 	
 		// instantiation
-		SQLRConnection con=new SQLRConnection(args[0],Integer.parseInt(args[1]), 
+		SQLRConnection con=new SQLRConnection(args[0],
+					(short)Integer.parseInt(args[1]), 
 						args[2],args[3],args[4],0,1);
 		SQLRCursor cur=new SQLRCursor(con);
 	
@@ -122,7 +123,7 @@ class sqlite {
 		System.out.println();
 	
 		System.out.println("AFFECTED ROWS: ");
-		checkSuccess(cur.affectedRows(),-1);
+		checkSuccess(cur.affectedRows(),0);
 		System.out.println();
 	
 		System.out.println("BIND BY NAME: ");
@@ -589,10 +590,11 @@ class sqlite {
 
 	    	System.out.println("COMMIT AND ROLLBACK: \n");
 	    	SQLRConnection secondcon=new SQLRConnection(args[0],
-				    	Integer.parseInt(args[1]), 
+				    	(short)Integer.parseInt(args[1]), 
 				    	args[2],args[3],args[4],0,1);
 	    	SQLRCursor secondcur=new SQLRCursor(secondcon);
-	    	checkSuccess(secondcur.sendQuery("select count(*) from testtable"),0);
+	    	checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
+	    	checkSuccess(secondcur.getField(0,0),"0");
 	    	checkSuccess(con.commit(),1);
 	    	checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
 	    	checkSuccess(secondcur.getField(0,0),"8");
