@@ -91,9 +91,9 @@ class sybase {
 		String	floatvar;
 		String[]	cols;
 		String[]	fields;
-		int	port;
+		short	port;
 		String	socket;
-		int	id;
+		short	id;
 		String	filename;
 		long[]	fieldlens;
 	
@@ -105,7 +105,8 @@ class sybase {
 	
 	
 		// instantiation
-		SQLRConnection con=new SQLRConnection(args[0],Integer.parseInt(args[1]), 
+		SQLRConnection con=new SQLRConnection(args[0],
+					(short)Integer.parseInt(args[1]), 
 						args[2],args[3],args[4],0,1);
 		SQLRCursor cur=new SQLRCursor(con);
 	
@@ -400,7 +401,7 @@ class sybase {
 		System.out.println();
 	
 		System.out.println("TOTAL ROWS: ");
-		checkSuccess(cur.totalRows(),-1);
+		checkSuccess(cur.totalRows(),0);
 		System.out.println();
 	
 		System.out.println("FIRST ROW INDEX: ");
