@@ -4,8 +4,8 @@
 # See the file COPYING for more information.
 
 
-use Firstworks::SQLRConnection;
-use Firstworks::SQLRCursor;
+use SQLRelay::Connection;
+use SQLRelay::Cursor;
 
 sub checkUndef {
 
@@ -53,9 +53,9 @@ if ($#ARGV+1<5) {
 }
 
 # instantiation
-$con=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1],
+$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1],
 					$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$cur=Firstworks::SQLRCursor->new($con);
+$cur=SQLRelay::Cursor->new($con);
 
 # get database type
 print("IDENTIFY: \n");
@@ -80,6 +80,7 @@ print("\n");
 
 print("BIND BY POSITION: \n");
 $cur->prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,NULL)");
+checkSuccess($cur->countBindVariables(),10);
 $cur->inputBind("1",2);
 $cur->inputBind("2",2);
 $cur->inputBind("3",2);
@@ -249,7 +250,7 @@ checkSuccess($cur->rowCount(),8);
 print("\n");
 
 print("TOTAL ROWS: \n");
-checkSuccess($cur->totalRows(),-1);
+checkSuccess($cur->totalRows(),0);
 print("\n");
 
 print("FIRST ROW INDEX: \n");
