@@ -4,8 +4,8 @@
 # See the file COPYING for more information.
 
 
-use Firstworks::SQLRConnection;
-use Firstworks::SQLRCursor;
+use SQLRelay::Connection;
+use SQLRelay::Cursor;
 
 sub checkUndef {
 
@@ -54,9 +54,9 @@ if ($#ARGV+1<5) {
 
 
 # instantiation
-$con=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1],
+$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1],
 		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$cur=Firstworks::SQLRCursor->new($con);
+$cur=SQLRelay::Cursor->new($con);
 
 # get database type
 print("IDENTIFY: \n");
@@ -83,11 +83,12 @@ checkSuccess($cur->sendQuery("insert into testtable values ('char4','01-Jan-2004
 print("\n");
 
 print("AFFECTED ROWS: \n");
-checkSuccess($cur->affectedRows(),-1);
+checkSuccess($cur->affectedRows(),0);
 print("\n");
 
 print("BIND BY NAME: \n");
 $cur->prepareQuery("insert into testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8)");
+checkSuccess($cur->countBindVariables(),8);
 $cur->inputBind("var1","char5");
 $cur->inputBind("var2","01-Jan-2005");
 $cur->inputBind("var3",5);
@@ -663,10 +664,9 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-$secondcon=Firstworks::SQLRConnection->new($ARGV[0],
-			$ARGV[1], 
+$secondcon=SQLRelay::Connection->new($ARGV[0],$ARGV[1], 
 		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$secondcur=Firstworks::SQLRCursor->new($secondcon);
+$secondcur=SQLRelay::Cursor->new($secondcon);
 checkSuccess($secondcur->sendQuery("select * from testtable order by testint"),1);
 checkSuccessString($secondcur->getField(0,0),"char1");
 checkSuccess($con->commit(),1);
