@@ -4,8 +4,8 @@
 # See the file COPYING for more information.
 
 
-use Firstworks::SQLRConnection;
-use Firstworks::SQLRCursor;
+use SQLRelay::Connection;
+use SQLRelay::Cursor;
 
 sub checkUndef {
 
@@ -53,9 +53,9 @@ if ($#ARGV+1<5) {
 
 
 # instantiation
-$con=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1],
+$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1],
 		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$cur=Firstworks::SQLRCursor->new($con);
+$cur=SQLRelay::Cursor->new($con);
 
 # get database type
 print("IDENTIFY: \n");
@@ -87,6 +87,7 @@ print("\n");
 
 print("BIND BY NAME: \n");
 $cur->prepareQuery("insert into testdb.testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8,:var9,:var10,:var11,:var12,:var13,:var14,:var15,:var16,:var17,:var18,NULL)");
+checkSuccess($cur->countBindVariables(),18);
 $cur->inputBind("var1",5);
 $cur->inputBind("var2",5);
 $cur->inputBind("var3",5);
@@ -232,8 +233,8 @@ checkSuccessString($cur->getColumnType(12),"CHAR");
 checkSuccessString($cur->getColumnType(13),"BLOB");
 checkSuccessString($cur->getColumnType(14),"CHAR");
 checkSuccessString($cur->getColumnType(15),"TINYBLOB");
-checkSuccessString($cur->getColumnType(16),"BLOB");
-checkSuccessString($cur->getColumnType(17),"BLOB");
+checkSuccessString($cur->getColumnType(16),"MEDIUMBLOB");
+checkSuccessString($cur->getColumnType(17),"LONGBLOB");
 checkSuccessString($cur->getColumnType(18),"TIMESTAMP");
 checkSuccessString($cur->getColumnType("testtinyint"),"TINYINT");
 checkSuccessString($cur->getColumnType("testsmallint"),"SMALLINT");
@@ -251,8 +252,8 @@ checkSuccessString($cur->getColumnType("testchar"),"CHAR");
 checkSuccessString($cur->getColumnType("testtext"),"BLOB");
 checkSuccessString($cur->getColumnType("testvarchar"),"CHAR");
 checkSuccessString($cur->getColumnType("testtinytext"),"TINYBLOB");
-checkSuccessString($cur->getColumnType("testmediumtext"),"BLOB");
-checkSuccessString($cur->getColumnType("testlongtext"),"BLOB");
+checkSuccessString($cur->getColumnType("testmediumtext"),"MEDIUMBLOB");
+checkSuccessString($cur->getColumnType("testlongtext"),"LONGBLOB");
 checkSuccessString($cur->getColumnType("testtimestamp"),"TIMESTAMP");
 print("\n");
 
@@ -270,11 +271,11 @@ checkSuccess($cur->getColumnLength(9),3);
 checkSuccess($cur->getColumnLength(10),8);
 checkSuccess($cur->getColumnLength(11),1);
 checkSuccess($cur->getColumnLength(12),41);
-checkSuccess($cur->getColumnLength(13),65538);
+checkSuccess($cur->getColumnLength(13),65535);
 checkSuccess($cur->getColumnLength(14),41);
-checkSuccess($cur->getColumnLength(15),257);
-checkSuccess($cur->getColumnLength(16),16777218);
-checkSuccess($cur->getColumnLength(17),16777218);
+checkSuccess($cur->getColumnLength(15),255);
+checkSuccess($cur->getColumnLength(16),16777215);
+checkSuccess($cur->getColumnLength(17),2147483647);
 checkSuccess($cur->getColumnLength(18),4);
 checkSuccess($cur->getColumnLength("testtinyint"),1);
 checkSuccess($cur->getColumnLength("testsmallint"),2);
@@ -289,11 +290,11 @@ checkSuccess($cur->getColumnLength("testtime"),3);
 checkSuccess($cur->getColumnLength("testdatetime"),8);
 checkSuccess($cur->getColumnLength("testyear"),1);
 checkSuccess($cur->getColumnLength("testchar"),41);
-checkSuccess($cur->getColumnLength("testtext"),65538);
+checkSuccess($cur->getColumnLength("testtext"),65535);
 checkSuccess($cur->getColumnLength("testvarchar"),41);
-checkSuccess($cur->getColumnLength("testtinytext"),257);
-checkSuccess($cur->getColumnLength("testmediumtext"),16777218);
-checkSuccess($cur->getColumnLength("testlongtext"),16777218);
+checkSuccess($cur->getColumnLength("testtinytext"),255);
+checkSuccess($cur->getColumnLength("testmediumtext"),16777215);
+checkSuccess($cur->getColumnLength("testlongtext"),2147483647);
 checkSuccess($cur->getColumnLength("testtimestamp"),4);
 print("\n");
 
@@ -316,7 +317,7 @@ checkSuccess($cur->getLongest(14),8);
 checkSuccess($cur->getLongest(15),9);
 checkSuccess($cur->getLongest(16),11);
 checkSuccess($cur->getLongest(17),9);
-checkSuccess($cur->getLongest(18),14);
+checkSuccess($cur->getLongest(18),19);
 checkSuccess($cur->getLongest("testtinyint"),1);
 checkSuccess($cur->getLongest("testsmallint"),1);
 checkSuccess($cur->getLongest("testmediumint"),1);
@@ -335,7 +336,7 @@ checkSuccess($cur->getLongest("testvarchar"),8);
 checkSuccess($cur->getLongest("testtinytext"),9);
 checkSuccess($cur->getLongest("testmediumtext"),11);
 checkSuccess($cur->getLongest("testlongtext"),9);
-checkSuccess($cur->getLongest("testtimestamp"),14);
+checkSuccess($cur->getLongest("testtimestamp"),19);
 print("\n");
 
 print("ROW COUNT: \n");
@@ -935,10 +936,9 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-$secondcon=Firstworks::SQLRConnection->new($ARGV[0],
-			$ARGV[1], 
+$secondcon=SQLRelay::Connection->new($ARGV[0],$ARGV[1], 
 		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$secondcur=Firstworks::SQLRCursor->new($secondcon);
+$secondcur=SQLRelay::Cursor->new($secondcon);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
 checkSuccessString($secondcur->getField(0,0),"8");
 checkSuccess($con->commit(),1);
