@@ -4,8 +4,8 @@
 # See the file COPYING for more information.
 
 
-use Firstworks::SQLRConnection;
-use Firstworks::SQLRCursor;
+use SQLRelay::Connection;
+use SQLRelay::Cursor;
 
 sub checkUndef {
 
@@ -52,9 +52,9 @@ if ($#ARGV+1<5) {
 }
 
 # instantiation
-$con=Firstworks::SQLRConnection->new($ARGV[0],$ARGV[1],
+$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1],
 		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$cur=Firstworks::SQLRCursor->new($con);
+$cur=SQLRelay::Cursor->new($con);
 
 # get database type
 print("IDENTIFY: \n");
@@ -87,11 +87,12 @@ checkSuccess($cur->sendQuery("insert into testtable values (4,4.4,'testchar4','t
 print("\n");
 
 print("AFFECTED ROWS: \n");
-checkSuccess($cur->affectedRows(),-1);
+checkSuccess($cur->affectedRows(),0);
 print("\n");
 
 print("BIND BY NAME: \n");
 $cur->prepareQuery("insert into testtable values (:var1,:var2,:var3,:var4)");
+checkSuccess($cur->countBindVariables(),4);
 $cur->inputBind("var1",5);
 $cur->inputBind("var2",5.5,4,1);
 $cur->inputBind("var3","testchar5");
@@ -557,11 +558,12 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-$secondcon=Firstworks::SQLRConnection->new($ARGV[0],
+$secondcon=SQLRelay::Connection->new($ARGV[0],
 				$ARGV[1], 
 				$ARGV[2],$ARGV[3],$ARGV[4],0,1);
-$secondcur=Firstworks::SQLRCursor->new($secondcon);
-checkSuccess($secondcur->sendQuery("select count(*) from testtable"),0);
+$secondcur=SQLRelay::Cursor->new($secondcon);
+checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
+checkSuccess($secondcur->getField(0,0),"0");
 checkSuccess($con->commit(),1);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
 checkSuccess($secondcur->getField(0,0),"8");
