@@ -101,7 +101,7 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("AFFECTED ROWS: \n");
-	checkSuccess(sqlrcur_affectedRows($cur),-1);
+	checkSuccess(sqlrcur_affectedRows($cur),0);
 	echo("\n");
 
 	echo("STORED PROCEDURE: \n");
@@ -227,7 +227,7 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("TOTAL ROWS: \n");
-	checkSuccess(sqlrcur_totalRows($cur),-1);
+	checkSuccess(sqlrcur_totalRows($cur),0);
 	echo("\n");
 
 	echo("FIRST ROW INDEX: \n");
