@@ -133,46 +133,46 @@ print "\n"
 
 print "OUTPUT BIND BY NAME: \n"
 cur.prepareQuery("begin  :numvar:=1; :stringvar:='hello'; :floatvar:=2.5; end;")
-cur.defineOutputBind("numvar",10)
-cur.defineOutputBind("stringvar",10)
-cur.defineOutputBind("floatvar",10)
+cur.defineOutputBindInteger("numvar")
+cur.defineOutputBindString("stringvar",10)
+cur.defineOutputBindDouble("floatvar")
 checkSuccess(cur.executeQuery(),1)
-numvar=cur.getOutputBind("numvar")
-stringvar=cur.getOutputBind("stringvar")
-floatvar=cur.getOutputBind("floatvar")
-checkSuccess(numvar,'1')
+numvar=cur.getOutputBindInteger("numvar")
+stringvar=cur.getOutputBindString("stringvar")
+floatvar=cur.getOutputBindDouble("floatvar")
+checkSuccess(numvar,1)
 checkSuccess(stringvar,'hello')
-checkSuccess(floatvar,'2.5')
+checkSuccess(floatvar,2.5)
 print "\n"
 
 print "OUTPUT BIND BY NAME: \n"
 cur.clearBinds()
-cur.defineOutputBind("1",10)
-cur.defineOutputBind("2",10)
-cur.defineOutputBind("3",10)
+cur.defineOutputBindInteger("1")
+cur.defineOutputBindString("2",10)
+cur.defineOutputBindDouble("3")
 checkSuccess(cur.executeQuery(),1)
-numvar=cur.getOutputBind("1")
-stringvar=cur.getOutputBind("2")
-floatvar=cur.getOutputBind("3")
-checkSuccess(numvar,'1')
+numvar=cur.getOutputBindInteger("1")
+stringvar=cur.getOutputBindString("2")
+floatvar=cur.getOutputBindDouble("3")
+checkSuccess(numvar,1)
 checkSuccess(stringvar,'hello')
-checkSuccess(floatvar,'2.5')
+checkSuccess(floatvar,2.5)
 print "\n"
 
 print "OUTPUT BIND BY NAME WITH VALIDATION: \n"
 cur.clearBinds()
-cur.defineOutputBind("numvar",10)
-cur.defineOutputBind("stringvar",10)
-cur.defineOutputBind("floatvar",10)
-cur.defineOutputBind("dummyvar",10)
+cur.defineOutputBindInteger("numvar")
+cur.defineOutputBindString("stringvar",10)
+cur.defineOutputBindDouble("floatvar")
+cur.defineOutputBindString("dummyvar",10)
 cur.validateBinds()
 checkSuccess(cur.executeQuery(),1)
-numvar=cur.getOutputBind("numvar")
-stringvar=cur.getOutputBind("stringvar")
-floatvar=cur.getOutputBind("floatvar")
-checkSuccess(numvar,'1')
+numvar=cur.getOutputBindInteger("numvar")
+stringvar=cur.getOutputBindString("stringvar")
+floatvar=cur.getOutputBindDouble("floatvar")
+checkSuccess(numvar,1)
 checkSuccess(stringvar,'hello')
-checkSuccess(floatvar,'2.5')
+checkSuccess(floatvar,2.5)
 print "\n"
 
 print "SELECT: \n"
@@ -241,7 +241,7 @@ checkSuccess(cur.rowCount(),8)
 print "\n"
 
 print "TOTAL ROWS: \n"
-checkSuccess(cur.totalRows(),-1)
+checkSuccess(cur.totalRows(),0)
 print "\n"
 
 print "FIRST ROW INDEX: \n"
@@ -402,9 +402,9 @@ print "\n"
 
 print "OUTPUT BIND: \n"
 cur.prepareQuery("begin :var1:='hello'; end;")
-cur.defineOutputBind("var1",10)
+cur.defineOutputBindString("var1",10)
 checkSuccess(cur.executeQuery(),1)
-checkSuccess(cur.getOutputBind("var1"),"hello")
+checkSuccess(cur.getOutputBindString("var1"),"hello")
 print "\n"
 
 print "ARRAY SUBSTITUTIONS: \n"
@@ -686,9 +686,9 @@ cur.prepareQuery("begin select testclob into :clobvar from testtable1;  select t
 cur.defineOutputBindClob("clobvar")
 cur.defineOutputBindBlob("blobvar")
 checkSuccess(cur.executeQuery(),1)
-clobvar=cur.getOutputBind("clobvar")
+clobvar=cur.getOutputBindClob("clobvar")
 clobvarlength=cur.getOutputBindLength("clobvar")
-blobvar=cur.getOutputBind("blobvar")
+blobvar=cur.getOutputBindBlob("blobvar")
 blobvarlength=cur.getOutputBindLength("blobvar")
 checkSuccess(clobvar,"hello")
 checkSuccess(clobvarlength,5)
@@ -747,7 +747,7 @@ checkSuccess(clobval,cur.getField(0,"testclob"))
 cur.prepareQuery("begin select testclob into :clobbindval from testtable2; end;")
 cur.defineOutputBindClob("clobbindval")
 checkSuccess(cur.executeQuery(),1)
-clobbindvar=cur.getOutputBind("clobbindval")
+clobbindvar=cur.getOutputBindClob("clobbindval")
 checkSuccess(cur.getOutputBindLength("clobbindval"),8*1024)
 checkSuccess(clobval,clobbindvar)
 cur.sendQuery("drop table testtable2")
