@@ -64,6 +64,7 @@ print "\n"
 
 print "BIND BY NAME: \n"
 cur.prepareQuery("insert into testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8)")
+checkSuccess(cur.countBindVariables(),8)
 cur.inputBind("var1",5)
 cur.inputBind("var2",5.5,4,2)
 cur.inputBind("var3",5.5,4,2)
@@ -675,6 +676,27 @@ print "\n"
 # drop existing table
 cur.sendQuery("drop table testtable")
 
+# stored procedures
+printf("STORED PROCEDURES: \n");
+cur.sendQuery("drop function testfunc(int)");
+checkSuccess(cur.sendQuery("create function testfunc(int) returns int as ' begin return $1; end;' language plpgsql"),1);
+cur.prepareQuery("select * from testfunc(:int)");
+cur.inputBind("int",5);
+checkSuccess(cur.executeQuery(),1);
+checkSuccess(cur.getField(0,0),"5");
+cur.sendQuery("drop function testfunc(int)");
+
+cur.sendQuery("drop function testfunc(int,char(20))");
+checkSuccess(cur.sendQuery("create function testfunc(int, char(20)) returns record as ' declare output record; begin select $1,$2 into output; return output; end;' language plpgsql"),1);
+cur.prepareQuery("select * from testfunc(:int,:char) as (col1 int, col2 char(20))");
+cur.inputBind("int",5);
+cur.inputBind("char","hello");
+checkSuccess(cur.executeQuery(),1);
+checkSuccess(cur.getField(0,0),"5");
+checkSuccess(cur.getField(0,1),"hello");
+cur.sendQuery("drop function testfunc(int,char(20))");
+printf("\n");
+
 # invalid queries...
 print "INVALID QUERIES: \n"
 checkSuccess(cur.sendQuery("select * from testtable order by testint"),0)
